<?php

class WC_GLS_Shipping_Method extends WC_Shipping_Method
{

    const ID = 'gls_shipping_method';

    public static $url_webservice = 'https://www.asmred.com/websrvs/ecm.asmx?wsdl';

	public $wsdl;
	public $guid;
	public $incoterm;
	public $rcs;
	public $retorno;
	public $valor_asegurado;
	public $bultos;
	public $peso;
	public $departamento;
	public $nombre_origen;
	public $direccion_origen;
	public $poblacion_origen;
	public $source_zip;
	public $etiqueta;
	public $order_status;
	
	public $method_order;
	public $has_settings;
	public $settings_html;

    /**
     * Constructor for your shipping class
     *
     * @access public
     * @return void
     */
    public function __construct($instance_id = 0)
    {
        $this->instance_id = absint($instance_id);
        $this->id = self::ID;
        $this->title = __('Envío GLS', 'woocommerce-gls-envios');
        $this->method_title = __('Envío GLS', 'woocommerce-gls-envios');
        $this->method_description = __('GLS Líder de calidad en logística de paquetería', 'woocommerce-gls-envios');
        $this->enabled = 'yes';
        $this->init();
    }

    /**
     * Init your settings
     *
     * @access public
     * @return void
     */
    public function init()
    {
        $this->supports = array(
            'shipping-zones',
            'instance-settings',
            'instance-settings-modal',
        );
        $this->init_settings();
        add_action('woocommerce_update_options_shipping_methods', array(&$this, 'process_admin_options'));
        add_action('woocommerce_update_options_shipping_' . $this->id, array(&$this, 'process_admin_options'));
    }

    public function init_settings()
    {
        /* LEGACY CONFIG */
        $this->wsdl = GLS_Settings::get_wsdl();
        $glsOptions = get_option('gls_envios_options');
        $this->guid = $glsOptions[GLS_Settings::$prefix . 'guid'];
        $this->incoterm = $glsOptions[GLS_Settings::$prefix . 'incoterm'];
        $this->rcs = (int) $glsOptions[GLS_Settings::$prefix . 'rcs'] == 1 ? 'Si' : 'No';
        $this->retorno = $glsOptions[GLS_Settings::$prefix . 'return'];
        $this->valor_asegurado = $glsOptions[GLS_Settings::$prefix . 'insured'];
        $this->bultos = $glsOptions[GLS_Settings::$prefix . 'packages'];
        $this->peso = $glsOptions[GLS_Settings::$prefix . 'weight'];
        $this->departamento = $glsOptions[GLS_Settings::$prefix . 'origin'];
        /* LEGACY SENDER DATA */
        $this->nombre_origen = $glsOptions[GLS_Settings::$prefix . 'sender_name'];
        $this->direccion_origen = $glsOptions[GLS_Settings::$prefix . 'sender_address'];
        $this->poblacion_origen = $glsOptions[GLS_Settings::$prefix . 'sender_city'];
        $this->source_zip = $glsOptions[GLS_Settings::$prefix . 'sender_postal_code'];
        /* LABEL TYPE */
        $this->etiqueta = $glsOptions[GLS_Settings::$prefix . 'tipo_etiqueta'];
        /* ORDER STATUS */
        $this->order_status = 'wc-gls-sent';
    }

    public function get_admin_options_html()
    {
		$zone_id = null;
		if (!empty($_REQUEST['zone_id'])){
			$zone_id = $_REQUEST['zone_id'];
        }
		if (empty($zone_id) && !empty($_REQUEST['instance_id'])){
			$zone_id = $this->get_shipping_zone_from_instance_id($_REQUEST['instance_id']);
        }
		if (is_admin() && !empty($zone_id)) {
            $role = isset($_REQUEST['role']) ? $_REQUEST['role'] : '';
            $zone = WC_Shipping_Zones::get_zone($zone_id);
           // $zone->zone_id = $zone_id;
            $services = self::getServices();
            $ranges = self::getRanges($role);
            $checked = self::getChecked($role);
            $path = plugin_dir_path(__DIR__);
            $uri = plugins_url('') . '/woocommerce-gls-envios/';
            ob_start();
            include $path . 'templates/views/services-cost-zone.php';
            return ob_get_clean();
        }
    }
	
	
	
	function get_shipping_zone_from_instance_id( $instance_id ){
		global $wpdb;

		$method_id = $this->id;
		$zone_id = $wpdb->get_col( "
			SELECT wszm.zone_id
			FROM {$wpdb->prefix}woocommerce_shipping_zone_methods as wszm
			WHERE wszm.instance_id = '$instance_id'
			AND wszm.method_id LIKE '$method_id'
		" );
		
		return reset($zone_id); 
	}

    /**
     * calculate_shipping function.
     *
     * @access public
     * @param mixed $package
     * @return void
     */
    public function calculate_shipping($package = array())
    {
        $weight = WC()->cart->get_cart_contents_weight();
		$cart = WC()->cart->get_cart();
		foreach ($cart as $cart_item){
			$i = 2;
			$productId = (!empty($cart_item['variation_id'])) ? $cart_item['variation_id'] : $cart_item['product_id'];
			while ( metadata_exists( 'post', $productId, '_weight'.$i ) ) {
				$extraWeight = get_post_meta( $productId, '_weight'.$i, true );
				$weight += $extraWeight * $cart_item['quantity'];
				$i++;
			}
		}
		$free_shipping = false;
		$coupons = WC()->cart->get_applied_coupons();
		if (!empty($coupons)) {
			foreach($coupons as $id_coupon){
				$coupon = new WC_Coupon($id_coupon);
				$free_shipping = $coupon->get_free_shipping();
			}
		}

        $amount = WC()->cart->cart_contents_total;
        $glsOptions = get_option('gls_envios_options');
		if ((int)$glsOptions[GLS_Settings::$prefix . 'total_taxes'] == 1){
			$taxes = WC()->cart->get_subtotal_tax();
			$amount += $taxes;
		}
        $shipping_zone = WC_Shipping_Zones::get_zone_matching_package($package);
        $customer = wp_get_current_user();
        $role = (int)$customer->ID > 0 ? current($customer->roles) : '';
        $rates = self::get_rates($shipping_zone->get_id(), $role, $amount, $weight);
		
        if (empty($rates)) {
            $rates = self::get_rates($shipping_zone->get_id(), '', $amount, $weight);
        }

        if (!empty($rates)) {
            foreach ($rates as $rate) {
				if ($free_shipping){
					//$rate['label'] .= " (gratis)";
					$rate['cost'] = 0;
				}
                parent::add_rate($rate);
            }
        }
    }

    public static function get_rates($zone_id, $role, $amount, $weight)
    {
        if (!empty($zone_id) && (!empty($amount) || !empty($weight))) {
            global $wpdb;

            $rules = $rates = array();
            $table_a = $wpdb->prefix . 'gls_services_cost';
            $table_b = $wpdb->prefix . 'gls_services';
			
			$base_country = get_option('woocommerce_default_country');			
			if(strlen($base_country)>2){
				$country_code = explode(":",$base_country)[0];
			} else {
				$country_code = $base_country;
			}
			
			$zoneObj = new WC_Shipping_Zone($zone_id);
			$zoneLocations = $zoneObj->get_zone_locations();
			$validServices = [];
			foreach ($zoneLocations as $zL){
				switch ($zL->type){
					case 'country':
					
						if ( $zL->code == 'ES' || $country_code == $zL->code){
							$validServices = array('gls10','gls14','gls24','buspar','economy','parcelshopgls');
						} elseif($country_code == 'ES' && $zL->code == 'PT') {
							$bpESPT = get_option('gls_bpespt');
							if (empty($bpESPT)){
								$validServices = array('economy','eurobusinessparcel','parcelshopgls');
							} else {
								$validServices = array('buspar','economy','eurobusinessparcel','parcelshopgls');
							}
						} else {
							$validServices = array('eurobusinessparcel');
						}
						
						$sdiCountries = get_option('gls_sdi_countries');
						if (!empty($sdiCountries) && is_array($sdiCountries)){
							if ($zL->code != 'ES' && in_array($zL->code, $sdiCountries)) {
								$validServices[] = 'shopdelint';
							}
						}
						
						break;
					case 'state':
						$splitCode = explode(':',$zL->code);
						if ( $splitCode[0] == 'ES' || $country_code == $splitCode[0]){
							$validServices = array('gls10','gls14','gls24','buspar','economy','parcelshopgls');
						} elseif($country_code == 'ES' && $splitCode[0] == 'PT') {
							$bpESPT = get_option('gls_bpespt');
							if (empty($bpESPT)){
								$validServices = array('economy','eurobusinessparcel','parcelshopgls');
							} else {
								$validServices = array('buspar','economy','eurobusinessparcel','parcelshopgls');
							}
						} else {
							$validServices = array('eurobusinessparcel');
						}
						
						
						$sdiCountries = get_option('gls_sdi_countries');
						if (!empty($sdiCountries) && is_array($sdiCountries)){
							if ($splitCode[0] != 'ES' && in_array($splitCode[0], $sdiCountries)) {
								$validServices[] = 'shopdelint';
							}
						}
						
						break;
				}
			}
			
			
            if (!empty($amount)) {
                $rules[] = '(gsc.`type` = 0 AND ' . (float) $amount . ' >= gsc.`min` AND ' . (float) $amount . ' <= gsc.`max`)';
            }
            if (!empty($weight)) {
                $rules[] = '(gsc.`type` = 1 AND ' . (float) $weight . ' >= gsc.`min` AND ' . (float) $weight . ' <= gsc.`max`)';
                $rules[] = '(gsc.`type` = 1 AND ' . (float) $weight . ' >= gsc.`min` AND 0.00 < gsc.`extra`)';
            }
            $sql = 'SELECT gsc.`type`,gsc.`service`, gsc.`cost`, gsc.`extra`, gsc.`max` FROM `' . $table_a . '` gsc
                LEFT JOIN `' . $table_b . '` gs ON gsc.`zone_id` = gs.`zone_id` AND gsc.`service` = gs.`service`AND gsc.`type` =  gs.`type` AND  gsc.`role` =  gs.`role` 
                WHERE gs.`service` IN ("'.implode('","',$validServices).'") AND gs.`enabled` = 1 AND gs.`zone_id` = ' . (int) $zone_id . ' AND (' . implode(' OR ', $rules) . ') AND (gsc.`role` = "' . $role . '" OR gsc.`role` = "")
                ORDER BY gsc.`type`, gsc.`cost` DESC';
            
			
            $rows = $wpdb->get_results($sql);

            if (!empty($rows)) {
                $available = array();
                foreach ($rows as $row) {
                    if (!isset($available[$row->service]) ||
                        (
                            $available[$row->service]->type == 0 &&
                            $row->type == 0 &&
                            $row->cost < $available[$row->service]->cost
                        ) || (
                            $available[$row->service]->type == 0 &&
                            $row->type == 1 &&
                            $row->cost > $available[$row->service]->cost
                        ) || (
                            $available[$row->service]->type == 1 &&
                            $row->type == 1 &&
                            $row->cost < $available[$row->service]->cost
                        )
                    ) {
                        $available[$row->service] = $row;
                    }
                }
                if (!empty($available)) {
                    $services = self::getServices();
                    foreach ($available as $row) {
						if ($row->extra > 0 && (float)$weight > (float)$row->max){
							$extraUnits = ceil((float)$weight - (float)$row->max);
							$weight_unit = get_option('woocommerce_weight_unit');
							$weight_unit = apply_filters('sod_wc_gls_weight_unit', $weight_unit);

							switch ($weight_unit) {
								case "g":
									$extraUnits = ceil($extraUnits / 1000);
									break;
								case "kg":
									$extraUnits = $extraUnits;
									break;
								case "lbs":
									$extraUnits = ceil(number_format($extraUnits * 0.45359237, 2));
									break;
								case "oz":
									$extraUnits = ceil($extraUnits / 16);
									break;
								default:
									break;
							}
							
							
							$cost = $row->cost + ($extraUnits*$row->extra);
							$rates[] = array(
								'id' => $row->service,
								'label' => $services[$row->service]['name'],
								'cost' => $cost,
								'meta_data' => array()
							);
						} else {
							$rates[] = array(
								'id' => $row->service,
								'label' => $services[$row->service]['name'],
								'cost' => $row->cost,
								'meta_data' => array(
									//'image' => 'https://picsum.photos/200/300'
								),
								//'taxes' => $taxes
							);
						}
                    }
                    return $rates;
                }
            }
        }
        return false;
    }

    public function admin_options()
    {
        WC_GLS_Shipping_Method::displayTable();
    }

    public static function getShippingMethodInstance($zone_id = null)
    {
        $zones = WC_Shipping_Zones::get_zones();

        if (isset($zones[$zone_id]) && !empty($zones[$zone_id]['shipping_methods'])) {
            foreach ($zones[$zone_id]['shipping_methods'] as $shipping_method) {
                if ($shipping_method->id == self::ID) {
                    return $shipping_method->instance_id;
                }
            }
        }
        return null;
    }

    public static function createShippingMethod($zone_id = null)
    {
        $zone = new WC_Shipping_Zone($zone_id);
        $instance_id = $zone->add_shipping_method(self::ID);
        $shipping_method = WC_Shipping_Zones::get_shipping_method($instance_id);
        $key = 'woocommerce_' . self::ID . '_' . $instance_id . '_settings';
        $data = array(
            'title' => $shipping_method->title,
            'tax_status' => $shipping_method->get_instance_option('tax_status'),
            'taxable' => $shipping_method->get_instance_option('taxable'),
            'cost' => $shipping_method->get_instance_option('cost'),
        );
        update_option($key, $data);
        return $instance_id;
    }

    public static function displayTable()
    {
        $data_store = WC_Data_Store::load('shipping-zone');
        $zones = $data_store->get_zones();
        $role = isset($_REQUEST['role']) ? $_REQUEST['role'] : '';
        $services = self::getServices();
        $checked = self::getChecked($role);
        $ranges = self::getRanges($role);
        $roles = self::getRoles();
        $path = plugin_dir_path(__DIR__);
        $uri = plugins_url('') . '/woocommerce-gls-envios/';
        include $path . 'templates/views/services-cost.php';
    }

    public static function getServices($keys = false)
    {
        return $keys ? array_keys(GLS_Settings::$services) : GLS_Settings::$services;
    }

    public static function getMaxRange($type = null, $zone_id = null, $role = null)
    {
        global $wpdb;
        $table = $wpdb->prefix . 'gls_services_cost';
        $sql = 'SELECT MAX(`max`) FROM `' . $table . '` 
            WHERE `type` = ' . (int) $type . ' 
            AND `zone_id` = ' . (int) $zone_id . ' 
            AND `role` = "' . $role . '"';
        return (float) $wpdb->get_var($sql);
    }

    public static function getRoles()
    {
        global $wp_roles;
        if (!isset($wp_roles)) {
            $wp_roles = new WP_Roles();
        }
        return $wp_roles->get_names();
    }

    public static function displayTableRanges($zone_id = null, $role = null, $type = null)
    {
        $zone = WC_Shipping_Zones::get_zone($zone_id);
        //$zone->zone_id = $zone_id;
        $services = self::getServices();
        $ranges = self::getRanges($role);
        $path = plugin_dir_path(__DIR__);        
        ob_start();        
        include $path . 'templates/views/services-cost-ranges.php';
        return ob_get_clean();
    }

    public static function rangeAdd($type = null, $zone_id = null, $role = null, $min = 0, $max = 0)
    {        
        $max_current = self::getMaxRange($type, $zone_id, $role);
        if ((empty($max_current) || (float) $min > (float) $max_current) && (float) $max > (float) $min) {
            global $wpdb;
            $services = self::getServices();
            $table = $wpdb->prefix . 'gls_services_cost';
            foreach ($services as $service => $conf) {
                $wpdb->insert($table, array(
                    'zone_id' => (int) $zone_id,
                    'role' => $role,
                    'service' => $service,
                    'type' => (int) $type,
                    'min' => (float) $min,
                    'max' => (float) $max,
                ));
            }
            return array(
                'zone_id' => $zone_id,
                'role' => $role,
                'type' => $type,
                'html' => self::displayTableRanges($zone_id, $role, $type),
            );
        } else if ((float) $min > (float) $max) {
            return array(
                'error' => __('Su valor máximo deber ser mayor que el valor mínimo', 'woocommerce-gls-envios'),
				'zone_id' => $zone_id,
                'role' => $role,
                'type' => $type,				
				'html' => self::displayTableRanges($zone_id, $role, $type)
			);
        } else {
            return array(
                'error' => __('Su valor minimo debe ser mayor que el mayor valor actual', 'woocommerce-gls-envios'),
				'zone_id' => $zone_id,
                'role' => $role,
                'type' => $type,
				'html' => self::displayTableRanges($zone_id, $role, $type)
			);
        }
    }

    public static function rangeDel($type = null, $zone_id = null, $role = null, $min = 0, $max = 0)
    {
        global $wpdb;
        $table = $wpdb->prefix . 'gls_services_cost';
        $wpdb->delete($table, array(
            'zone_id' => (int) $zone_id,
            'role' => $role,
            'type' => (int) $type,
            'min' => (float) $min,
            'max' => (float) $max,
        ));
        return array(
            'zone_id' => $zone_id,
            'role' => $role,
            'type' => $type,
            'html' => self::displayTableRanges($zone_id, $role, $type),
        );
    }

    public static function getRanges($role = null)
    {
        global $wpdb;
        $ranges = array();
        $table_a = $wpdb->prefix . 'gls_services_cost';
        $table_b = $wpdb->prefix . 'gls_services';
        $sql = 'SELECT gsc.*,IFNULL(gs.`enabled`, 0) AS `enabled` FROM `' . $table_a . '` gsc
            LEFT JOIN `' . $table_b . '` gs ON gsc.`zone_id` = gs.`zone_id` AND gsc.`service` = gs.`service` AND gsc.`role` = gs.`role` AND gsc.`type` = gs.`type` 
            WHERE gsc.`role` = "' . $role . '" 
            ORDER BY gsc.`zone_id`,gsc.`service`,gsc.`type`,gsc.`min`,gsc.`max`,gsc.`cost` ASC';
		$rows = $wpdb->get_results($sql);
        if (!empty($rows)) {
            foreach ($rows as $k => $row) {
                $ranges[$row->zone_id][$row->service][$row->type][] = array(
                    'enabled' => $row->enabled,
                    'min' => $row->min,
                    'max' => $row->max,
                    'cost' => $row->cost,
                    'extra' => $row->extra,
                );
            }
        }
        return $ranges;
    }

    public static function getChecked($role = null)
    {
        global $wpdb;
        $checked = array();
        $table = $wpdb->prefix . 'gls_services';
        $sql = 'SELECT * FROM `' . $table . '` WHERE `role` = "' . $role . '"';        
        $rows = $wpdb->get_results($sql);
        if (!empty($rows)) {
            foreach ($rows as $k => $row) {
                $checked[$row->zone_id][$row->service][$row->type] = $row->enabled;
            }
        }
        return $checked;
    }

    public static function checkService($zone_id = null, $role = null, $service = null, $type = null, $enabled = null)
    {
        if (!self::getShippingMethodInstance($zone_id)) {
            self::createShippingMethod($zone_id);
        }
        global $wpdb;
        $table = $wpdb->prefix . 'gls_services';
        $sql = 'INSERT INTO `' . $table . '` (`zone_id`, `role`, `service`, `type`, `enabled`)
            VALUES (' . (int) $zone_id . ',"' . $role . '","' . $service . '","' . $type . '",' . (int) $enabled . ')
            ON DUPLICATE KEY UPDATE `enabled` = VALUES(`enabled`)';
        $wpdb->query($sql);
    }

    public static function costUpdate($type = null, $zone_id = null, $role = null, $service = null, $min = null, $max = null,$extra = null, $cost = null)
    {
        global $wpdb;
        $table = $wpdb->prefix . 'gls_services_cost';
		$sql = 'SELECT * FROM ' . $table . '
            WHERE `type` = "' . $type . '" AND `zone_id` = "' . $zone_id . '"' . ((!empty($role))? ' AND `role` = "' . $role . '"' : '') . ' AND `service` = "' . $service . '" AND `min` = "' . $min . '" AND `max` = "' . $max . '"';
		$rows = $wpdb->get_results($sql); 
        if (!empty($rows)) {
			if ($extra == 'null'){
				$wpdb->update(
					$table,
					array(
						'cost' => (float)$cost,
					),
					array(
						'type' => $type,
						'zone_id' => $zone_id,
						'role' => $role,
						'service' => $service,
						'min' => $min,
						'max' => $max,
					)
				);
			} else {
				$wpdb->update(
					$table,
					array(
						'extra' => 0
					),
					array(
						'type' => $type,
						'zone_id' => $zone_id,
						'role' => $role,
						'service' => $service
					)
				);
				$wpdb->update(
					$table,
					array(
						'extra' => (float)$extra
					),
					array(
						'type' => $type,
						'zone_id' => $zone_id,
						'role' => $role,
						'service' => $service,
						'min' => $min,
						'max' => $max,
					)
				);
			}
		} else {
			if ($extra == 'null'){
				$wpdb->insert(
					$table,
					array(
						'cost' => (float)$cost,
						'type' => $type,
						'zone_id' => $zone_id,
						'role' => $role,
						'service' => $service,
						'min' => $min,
						'max' => $max,
					)
				);
			} else {
				$wpdb->update(
					$table,
					array(
						'extra' => 0
					),
					array(
						'type' => $type,
						'zone_id' => $zone_id,
						'role' => $role,
						'service' => $service
					)
				);
				$wpdb->insert(
					$table,
					array(
						'extra' => (float)$extra,
						'type' => $type,
						'zone_id' => $zone_id,
						'role' => $role,
						'service' => $service,
						'min' => $min,
						'max' => $max,
					)
				);
			}
		}
    }
}



class WC_GLS_Shipping_Method_Gls10 extends WC_GLS_Shipping_Method
{
	const ID = 'gls10';
	public function __construct($instance_id = 0)
    {
        $this->instance_id = absint($instance_id);
        $this->id = self::ID;
        $this->title = __('Envío GLS - Express10:30', 'woocommerce-gls-envios');
        $this->method_title = __('Envío GLS - Express10:30', 'woocommerce-gls-envios');
        $this->method_description = __('GLS Líder de calidad en logística de paquetería', 'woocommerce-gls-envios');
        $this->enabled = 'yes';
        $this->init();
    }
}
class WC_GLS_Shipping_Method_Gls14 extends WC_GLS_Shipping_Method
{
	const ID = 'gls14';
   public function __construct($instance_id = 0)
    {
        $this->instance_id = absint($instance_id);
        $this->id = self::ID;
        $this->title = __('Envío GLS - Express14:00', 'woocommerce-gls-envios');
        $this->method_title = __('Envío GLS - Express14:00', 'woocommerce-gls-envios');
        $this->method_description = __('GLS Líder de calidad en logística de paquetería', 'woocommerce-gls-envios');
        $this->enabled = 'yes';
        $this->init();
    }
}
class WC_GLS_Shipping_Method_Gls24 extends WC_GLS_Shipping_Method
{
	const ID = 'gls24';
   public function __construct($instance_id = 0)
    {
        $this->instance_id = absint($instance_id);
        $this->id = self::ID;
        $this->title = __('Envío GLS - Express19:00', 'woocommerce-gls-envios');
        $this->method_title = __('Envío GLS - Express19:00', 'woocommerce-gls-envios');
        $this->method_description = __('GLS Líder de calidad en logística de paquetería', 'woocommerce-gls-envios');
        $this->enabled = 'yes';
        $this->init();
    }
}
class WC_GLS_Shipping_Method_Buspar extends WC_GLS_Shipping_Method
{
	const ID = 'buspar';
   public function __construct($instance_id = 0)
    {
        $this->instance_id = absint($instance_id);
        $this->id = self::ID;
        $this->title = __('Envío GLS - BusinessParcel', 'woocommerce-gls-envios');
        $this->method_title = __('Envío GLS - BusinessParcel', 'woocommerce-gls-envios');
        $this->method_description = __('GLS Líder de calidad en logística de paquetería', 'woocommerce-gls-envios');
        $this->enabled = 'yes';
        $this->init();
    }
}
class WC_GLS_Shipping_Method_Economy extends WC_GLS_Shipping_Method
{
	const ID = 'economy';
   public function __construct($instance_id = 0)
    {
        $this->instance_id = absint($instance_id);
        $this->id = self::ID;
        $this->title = __('Envío GLS - Economy', 'woocommerce-gls-envios');
        $this->method_title = __('Envío GLS - Economy', 'woocommerce-gls-envios');
        $this->method_description = __('GLS Líder de calidad en logística de paquetería', 'woocommerce-gls-envios');
        $this->enabled = 'yes';
        $this->init();
    }
}
class WC_GLS_Shipping_Method_Ebp extends WC_GLS_Shipping_Method
{
	const ID = 'eurobusinessparcel';
   public function __construct($instance_id = 0)
    {
        $this->instance_id = absint($instance_id);
        $this->id = self::ID;
        $this->title = __('Envío GLS - EBP', 'woocommerce-gls-envios');
        $this->method_title = __('Envío GLS - EBP', 'woocommerce-gls-envios');
        $this->method_description = __('GLS Líder de calidad en logística de paquetería', 'woocommerce-gls-envios');
        $this->enabled = 'yes';
        $this->init();
    }
}
class WC_GLS_Shipping_Method_Parcelshopgls extends WC_GLS_Shipping_Method
{
	const ID = 'parcelshopgls';
   public function __construct($instance_id = 0)
    {
        $this->instance_id = absint($instance_id);
        $this->id = self::ID;
        $this->title = __('Envío GLS - ParcelShop', 'woocommerce-gls-envios');
        $this->method_title = __('Envío GLS - ParcelShop', 'woocommerce-gls-envios');
        $this->method_description = __('GLS Líder de calidad en logística de paquetería', 'woocommerce-gls-envios');
        $this->enabled = 'yes';
        $this->init();
    }
}
class WC_GLS_Shipping_Method_Shopdelint extends WC_GLS_Shipping_Method
{
	const ID = 'shopdelint';
   public function __construct($instance_id = 0)
    {
        $this->instance_id = absint($instance_id);
        $this->id = self::ID;
        $this->title = __('Envío GLS - Shop Delivery Internacional', 'woocommerce-gls-envios');
        $this->method_title = __('Envío GLS - Shop Delivery Internacional', 'woocommerce-gls-envios');
        $this->method_description = __('GLS Líder de calidad en logística de paquetería', 'woocommerce-gls-envios');
        $this->enabled = 'yes';
        $this->init();
    }
}