<?php

if (!class_exists('WP_List_Table')) {
    require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}
class GLS_List_Table extends WP_List_Table
{
    public $example_data = array(
        array('ID' => 1,
            'orderid' => '',
            'cliente' => '',
            'status' => '',
            'precio' => '',
            'fecha_pedido' => '',
            'actions' => '',
        ),
    );

    public $found_data = array();

    public function __construct()
    {
        global $status, $page;
        parent::__construct(array(
            'singular' => __('envío', 'woocommerce-gls-envios'),
            'plural' => __('envíos', 'woocommerce-gls-envios'),
            'ajax' => false,
        ));

        add_action('admin_head', array(&$this, 'admin_header'));
    }

    public function admin_header()
    {
        $page = (isset($_GET['page'])) ? esc_attr($_GET['page']) : false;
        if (
		'gls' != $page && 
		'gls-manifiestos-submenu-page' != $page && 
		'gls-pedidos-submenu-page' != $page && 
		'gls-manifiestos2-submenu-page' != $page) {
            return;
        }
        wp_enqueue_script('jquery-ui-timepicker-addon', 'https://cdnjs.cloudflare.com/ajax/libs/jquery-ui-timepicker-addon/1.6.3/jquery-ui-timepicker-addon.min.js', array());
        wp_enqueue_style('jquery-ui-timepicker-addon', 'https://cdnjs.cloudflare.com/ajax/libs/jquery-ui-timepicker-addon/1.6.3/jquery-ui-timepicker-addon.min.css', array());
    }

    public function no_items()
    {
        _e('No hay envios de GLS.');
    }

    public function column_default($item, $column_name)
    {
        switch ($column_name) {
            case 'orderid':
            case 'fecha_pedido':
                return $item[$column_name];
            default:
                return $item[$column_name];
        }
    }

    public function get_sortable_columns()
    {
        $sortable_columns = array(
            /*  'orderid'  => array('orderid',false),
        'fecha_pedido' => array('fecha_pedido',false) */
        );
        return $sortable_columns;
    }

    public function get_columns()
    {
        $columns = array(
            'cb' => '<input type="checkbox" />',
            'orderid' => __('Pedido', 'woocommerce-gls-envios'),
            'cliente' => __('Cliente', 'woocommerce-gls-envios'),
            'status' => __('Estado', 'woocommerce-gls-envios'),
            'precio' => __('Precio', 'woocommerce-gls-envios'),
            'fecha_pedido' => __('Fecha pedido', 'woocommerce-gls-envios'),
            'actions' => __('Acciones', 'woocommerce-gls-envios'),
        );
        return $columns;
    }

    public function usort_reorder($a, $b)
    {
        $orderby = (!empty($_GET['orderby'])) ? $_GET['orderby'] : 'fecha_pedido';
        $order = (!empty($_GET['order'])) ? $_GET['order'] : 'desc';
        $result = strcmp($a[$orderby], $b[$orderby]);
        return ($order === 'asc') ? $result : -$result;
    }

    public function column_orderid($item)
    {
        $actions = array(
            //'edit'      => sprintf('<a href="?page=%s&action=%s&glsorder=%s">Edit</a>',$_REQUEST['page'],'edit',$item['ID'])
        );
        return sprintf('%1$s %2$s', $item['orderid'], $this->row_actions($actions));
    }

    public function get_bulk_actions()
    {
        $actions = array(
            'sendgls' => 'Enviar a GLS',
            'printtag' => 'Imprimir etiquetas',
        );

        return $actions;
    }

    public function process_bulk_action()
    {
		//wp_die('Error de seguridad'); 
        if (empty($_REQUEST['doaction'])) {
            return true;
        }
        if (isset($_REQUEST['_wpnonce']) && !empty($_REQUEST['_wpnonce'])) {
            $nonce = filter_input(INPUT_POST, '_wpnonce', FILTER_SANITIZE_STRING);
            $action = 'bulk-' . $this->_args['plural'];
            if (!wp_verify_nonce($nonce, $action)) {
                wp_die('Error de seguridad');
            }

        }
        $action = $this->current_action();
        switch ($action) {
            case 'sendgls':
                $wooGlsEnviosPrint = new WooCommerce_Gls_Envios_Print();
                foreach ($_REQUEST['orderid'] as $orderid) {
                    $wooGlsEnviosPrint->generate_gls_envio('etiqueta', $orderid, 2);
                }
                break;
            case 'printtag':
                $wooGlsEnviosPrint = new WooCommerce_Gls_Envios_Print();
                foreach ($_REQUEST['orderid'] as $orderid) {
                    $wooGlsEnviosPrint->generate_gls_envio('etiqueta', $orderid, 2);
                }
                $wooGlsEnviosPrint->multietiquetas($_REQUEST['orderid']);
                break;
            default:
                return true;
                break;
        }
        return true;
    }

    public function display_tablenav($which)
    {
        if ($which == 'top') {
            $uri = plugins_url('') . '/woocommerce-gls-envios/';
            include plugin_dir_path(dirname(__FILE__)) . 'templates/views/orders-nav.php';
        }
    }

    public function extra_tablenav($which)
    {
        if ($which == 'top') {
            do_action('restrict_manage_posts', 'shop_order', 'top');
        }
    }

    public function column_cb($item)
    {
        return sprintf(
            '<input type="checkbox" name="orderid[]" value="%s" />', $item['ID']
        );
    }
	
    public function prepare_items()
    {
        global $wpdb;

        if (!$this->process_bulk_action()) {
            return false;
        }

        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);
        usort($this->example_data, array(&$this, 'usort_reorder'));
        $per_page = 50;
        $current_page = $this->get_pagenum();

        $orderby = (!empty($_GET['orderby'])) ? $_GET['orderby'] : 'fecha_pedido';
        $order = (!empty($_GET['order'])) ? $_GET['order'] : 'desc';
        $paged = isset($_REQUEST['paged']) ? max(0, intval($_REQUEST['paged']) - 1) : 0;

        $dateRange = empty($_REQUEST['glsDateRange']) ? date('Y-m-d', time() - 86400) : $_REQUEST['glsDateRange'];
        $dateTo = empty($_REQUEST['glsDateTo']) ? '' : $_REQUEST['glsDateTo'];
        $status = (!empty($_REQUEST['post_status']) && $_REQUEST['post_status'] != '-1') ? $_REQUEST['post_status'] : false;

        $services = WC_GLS_Shipping_Method::getServices(true);

		if ( !class_exists( \Automattic\WooCommerce\Internal\DataStores\Orders\CustomOrdersTableController::class ) ){
			$post_type = 'shop_order';
		} else {
			$post_type = 'shop_order_placehold';
		}

		$openCarrier = get_option('gls_opencarrier');
		if ($openCarrier){
			$orderSql = "SELECT order_items.order_id
				FROM {$wpdb->prefix}woocommerce_order_items as order_items
				LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id
				LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID
				WHERE posts.post_type IN ('shop_order','shop_order_placehold')
				AND order_items.order_item_type = 'shipping'
				AND order_item_meta.meta_key = 'method_id'
				" . ((!empty($dateRange)) ? "AND posts.post_date >= '" . $dateRange . "'" : '') . "
				" . ((!empty($dateTo)) ? "AND posts.post_date <= '" . $dateTo . "'" : '') . "
				" . (($status) ? "AND posts.post_status = '" . $status . "'" : '') . "
				ORDER BY order_id DESC ";

		} else {
			$orderSql = "SELECT order_items.order_id
				FROM {$wpdb->prefix}woocommerce_order_items as order_items
				LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id
				LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID
				WHERE posts.post_type IN ('shop_order','shop_order_placehold')
				AND order_items.order_item_type = 'shipping'
				AND order_item_meta.meta_key = 'method_id'
				AND order_item_meta.meta_value IN('" . implode("','", $services) . "')
				" . ((!empty($dateRange)) ? "AND posts.post_date >= '" . $dateRange . "'" : '') . "
				" . ((!empty($dateTo)) ? "AND posts.post_date <= '" . $dateTo . "'" : '') . "
				" . (($status) ? "AND posts.post_status = '" . $status . "'" : '') . "
				ORDER BY order_id DESC ";
			
		}
	error_log("\r\n[" . date("r") . "] Consulta pedidos :" . $orderSql, 3, str_replace('classes', 'log', plugin_dir_path(__FILE__)) . "/".date('Ymd').".log");

		$results = $wpdb->get_col($orderSql);
		$total_items = count($results);
        $this->found_data = array_slice($results, (($current_page - 1) * $per_page), $per_page);
        $items = array();
        foreach ($this->found_data as $orderId) {
            $order = wc_get_order($orderId);
            $order_status = $order->get_status();
            $shippings = $order->get_items('shipping');
            foreach ($shippings as $shipping) {
                $method_id = $shipping->get_method_id();
            }

            $glsValora = new WC_GLS_Shipping_Method;
            $codbarras = $order->get_meta('codbarras');
            $gen = 0;
            if (!empty($codbarras)) {
                $gen = $codbarras;
            } else {
                $gen = 1;
            }
			$gls_estado = $order->get_meta( 'gls_estado' );
			$gls_status_history_raw = $order->get_meta( 'gls_state_history' );
			$gls_status_history_txt = '';
			if (!empty($gls_status_history_raw)){
				$state_history = json_decode($gls_status_history_raw,true);
				foreach ($state_history as $state){
					$gls_status_history_txt .= $state['date'].' - '.$state['text']."<br>";
				}
			}
			$gls_retorno = $order->get_meta( 'gls_retorno' );
			$gls_bultos = $order->get_meta( 'gls_bultos' );
			$gls_rcs = $order->get_meta( 'gls_rcs' );
			$gls_departamento = $order->get_meta( 'gls_departamento' );
			$gls_valor_asegurado = $order->get_meta( 'gls_valor_asegurado' );
			$validServices = GLS_Settings::$services;


            if ('processing' == $order_status || $gen != 1) {
                if (empty($gls_retorno) && (int)$gls_estado <= 0){
					if ('eurobusinessparcel' == $method_id || 'shopdelint' == $method_id) {                        
						$gls_incoterm = $order->get_meta( 'gls_incoterm' );
						ob_start();
						include plugin_dir_path(dirname(__FILE__)) . 'templates/views/table-actions-eurobusinessparcel.php';
						$toolbar = ob_get_clean();
					} else {
						ob_start();
						include plugin_dir_path(dirname(__FILE__)) . 'templates/views/table-actions-common.php';
						$toolbar = ob_get_clean();
					}
				} else {
					$toolbar = '';
				}
            } else {
                $toolbar = __('Revise el estado de su pedido. Lo más probable es que esté pendiente la aprobación de pago.', 'woocommerce-gls-envios');
            }
            
            if ($gen == 1) {
                $action =  $toolbar;
            } else {
                $action = $gen .
                    ' | <a href="admin-ajax.php?action=generate_gls_envio&template_type=tracking&order_id=' . $orderId . '" id="barras" title="' . __('Seguimiento de envío', 'woocommerce-gls-envios') . '" target="_blank">
                    ' . __('Seguimiento de envío', 'woocommerce-gls-envios') . '
					</a>' .
                    ' | <a href="admin-ajax.php?action=generate_gls_envio&template_type=etiqueta&order_id=' . $orderId . '" id="barras" class="gls_label_print" title="' . __('Ver etiqueta', 'woocommerce-gls-envios') . '" target="_blank">
                    ' . __('Ver etiqueta', 'woocommerce-gls-envios') . '
					</a>' . $toolbar;
            }

            $edit_order_url = $order->get_edit_order_url();

			$dateCreated = $order->get_date_created();
			if ($dateCreated) {
				$orderDate = $dateCreated->format('d/m/Y');
			} else {
				$orderDate = '-';
			}
            $items[] = array(
                'ID' => $orderId,
                'orderid' => '<a href="' . $edit_order_url . '" target="_blank">' . $orderId . '</a>',
                'cliente' => $order->get_billing_first_name() . ' ' . $order->get_billing_last_name(),
                'status' => '<div class="tooltip top">'.((!empty($gls_status_history_txt))?'<span class="tiptext">'.$gls_status_history_txt.'</span>':'') . wc_get_order_status_name($order->get_status()).(!empty($gls_estado)?' ('.$gls_estado.')':'').'</div>',
                'precio' => $order->get_total(),
                'fecha_pedido' => $orderDate,
                'actions' => $action,
            );
        }

       $this->set_pagination_args(array(
            'total_items' => $total_items,
            'per_page' => $per_page,
            'total_pages' => ceil($total_items / $per_page),
        ));
        $this->items = $items;
    }

} //class

class GLS_Manifiestos_List_Table extends WP_List_Table
{
    public $example_data = array();
    public $found_data = array();

    public function __construct()
    {
        global $status, $page;
        parent::__construct(array(
            'singular' => __('envío', 'woocommerce-gls-envios'),
            'plural' => __('envíos', 'woocommerce-gls-envios'),
            'ajax' => false,
        ));
        add_action('admin_head', array(&$this, 'admin_header'));
    }

    public function admin_header()
    {
        $page = (isset($_GET['page'])) ? esc_attr($_GET['page']) : false;
        if (
		'gls' != $page && 
		'gls-manifiestos-submenu-page' != $page && 
		'gls-pedidos-submenu-page' != $page && 
		'gls-manifiestos2-submenu-page' != $page) {
            return;
        }
        wp_enqueue_script('jquery-ui-timepicker-addon', 'https://cdnjs.cloudflare.com/ajax/libs/jquery-ui-timepicker-addon/1.6.3/jquery-ui-timepicker-addon.min.js', array());
        wp_enqueue_style('jquery-ui-timepicker-addon', 'https://cdnjs.cloudflare.com/ajax/libs/jquery-ui-timepicker-addon/1.6.3/jquery-ui-timepicker-addon.min.css', array());
    
       echo '<style type="text/css">';
        echo '.wp-list-table .column-codbarras { width: 10%;}';
        echo '.wp-list-table .column-orderid { width: 10%;}';
        echo '.wp-list-table .column-precio { width: 5%;}#wpfooter{display: none;}';
		echo '.extended .wp-list-table .column-codbarras { width: 30%;}';
        echo '.extended .wp-list-table .column-orderid { width: 60%;}';
        echo '.extended .wp-list-table .column-precio { width: 10%;}';
        echo '</style>';
    }

    public function no_items()
    {
        _e('No hay envios de GLS.');
    }

    public function column_default($item, $column_name)
    {
        switch ($column_name) {
            case 'orderid':
            case 'fecha_pedido':
                return $item[$column_name];
            default:
                return $item[$column_name];
        }
    }

    public function get_sortable_columns()
    {
        $sortable_columns = array(
            /*  'orderid'  => array('orderid',false),
        'fecha_pedido' => array('fecha_pedido',false) */
        );
        return $sortable_columns;
    }

    public function get_columns()
    {
        $columns = array(
            'codbarras' => __('Cod. Barras', 'woocommerce-gls-envios'),
            'customer' => __('Info entrega', 'woocommerce-gls-envios'),
            'precio' => __('Total', 'woocommerce-gls-envios'),
        );
        return $columns;
    }

    public function usort_reorder($a, $b)
    {
        $orderby = (!empty($_GET['orderby'])) ? $_GET['orderby'] : 'orderid';
        $order = (!empty($_GET['order'])) ? $_GET['order'] : 'desc';
        $result = strcmp($a[$orderby], $b[$orderby]);
        return ($order === 'asc') ? $result : -$result;
    }

    public function get_bulk_actions()
    {
        $actions = array(
            'csv' => 'CSV-EXCEL',
			//'pdf' => 'PDF',
            'print' => 'IMPRIMIR',
        );
        return $actions;
    }

    public function process_bulk_action()
    {
        if (empty($_REQUEST['doaction'])) {
            return;
        }
        if (isset($_REQUEST['_wpnonce']) && !empty($_REQUEST['_wpnonce'])) {
            $nonce = filter_input(INPUT_POST, '_wpnonce', FILTER_SANITIZE_STRING);
            $action = 'bulk-' . $this->_args['plural'];
            if (!wp_verify_nonce($nonce, $action)) {
                wp_die('Error de seguridad');
            }

        }
        $action = $this->current_action();
        switch ($action) {
            case 'csv':
                ob_end_clean();
                $csv = '"MANIFIESTO DE CARGA GLS";' . "\n";
                if (!empty($this->items)) {
					foreach ($this->items as $item) {
						unset($item['precio']);
						$csv .= '"' . str_replace('<br>',"\n",implode('";"', $item)) . '"' . "\n";
					}
                }
                header("Content-Disposition: attachment; filename=manifiestos.csv");
                header("Pragma: no-cache");
                header("Expires: 0");
                header("Content-type: application/x-msdownload", true, 200);
                echo chr(239) . chr(187) . chr(191) . $csv;
                die();
                break;
            case 'pdf':
                wp_die('pdf');
                break;
            case 'print':
                /* $bultos = 0;
                if (!empty($_POST['orderid'])) {
                    foreach ($_POST['orderid'] as $orderid) {
                        foreach ($this->items as $item) {
                            if ($item['ID'] == $orderid) {
                                $bultos += $item['bultos'];
                            }
                        }
                    }
                } */
				$logoUrl = plugins_url('../images/logo-gls.png', __FILE__);
                ?>
				<script>
					jQuery(window).load(function(){
						jQuery( ".toggle-row" ).remove(  );
						jQuery( ".check-column input" ).remove(  );
						var divToPrint=document.getElementById("printTable").getElementsByTagName('table')[0];
						newWin= window.open("");
						newWin.document.write('<h1><img style="height: 40px;" src="<?php echo $logoUrl; ?>">&nbsp;<?=__('Manifiesto de carga', 'woocommerce-gls-envios')?></h1><h2><?php echo date('d/m/Y')?></h2>'+divToPrint.outerHTML);
						newWin.print();
						newWin.close();
					});
				</script>
				<?php
				break;
            default:
                return;
                break;
        }
        return;
    }

    public function display_tablenav($which)
    {
        if ($which == 'top') {
            $uri = plugins_url('') . '/woocommerce-gls-envios/';
            include plugin_dir_path(dirname(__FILE__)) . 'templates/views/manifest-nav.php';
        }
    }

    public function extra_tablenav($which)
    {
        //parent::extra_tablenav( $which );
        if ($which == 'top') {
            do_action('restrict_manage_posts', 'shop_order', 'top');
        }

    }
    public function column_cb($item)
    {
        return sprintf(
            '<input type="hidden" name="orderid[]" value="%s" />', $item['ID']
        );
    }

    public function prepare_manifiestos()
    {
        global $wpdb;
		
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);
        usort($this->example_data, array(&$this, 'usort_reorder'));
        $per_page = 50;
        $current_page = $this->get_pagenum();

        $orderby = (!empty($_GET['orderby'])) ? $_GET['orderby'] : 'fecha_pedido';
        $order = (!empty($_GET['order'])) ? $_GET['order'] : 'desc';
        $paged = isset($_REQUEST['paged']) ? max(0, intval($_REQUEST['paged']) - 1) : 0;

        $services = WC_GLS_Shipping_Method::getServices(true);

        $dateRange = empty($_REQUEST['glsDateRange']) ? date('Y-m-d', time() - 86400) : $_REQUEST['glsDateRange'];
        $dateTo = empty($_REQUEST['glsDateTo']) ? '' : $_REQUEST['glsDateTo'];
        $status = (!empty($_REQUEST['post_status']) && $_REQUEST['post_status'] != '-1') ? $_REQUEST['post_status'] : false;

        if ( !class_exists( \Automattic\WooCommerce\Internal\DataStores\Orders\CustomOrdersTableController::class ) ){
			$post_type = 'shop_order';
		} else {
			$post_type = 'shop_order_placehold';
		}
		$openCarrier = get_option('gls_opencarrier');
		if ($openCarrier){
			$orderSql = "SELECT order_items.order_id 
				FROM {$wpdb->prefix}woocommerce_order_items as order_items 
				LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id 
				LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID 
				WHERE posts.post_type IN ('shop_order','shop_order_placehold')
				AND order_items.order_item_type = 'shipping' 
				AND order_item_meta.meta_key = 'method_id' 
				" . ((!empty($dateRange)) ? "AND posts.post_date >= '" . $dateRange . "'" : '') . " 
				" . ((!empty($dateTo)) ? "AND posts.post_date <= '" . $dateTo . "'" : '') . " 
				" . (($status) ? "AND posts.post_status = '" . $status . "'" : '') . "
				ORDER BY order_id DESC";
		} else {
			$orderSql = "SELECT order_items.order_id 
				FROM {$wpdb->prefix}woocommerce_order_items as order_items 
				LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id 
				LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID 
				WHERE posts.post_type IN ('shop_order','shop_order_placehold')
				AND order_items.order_item_type = 'shipping' 
				AND order_item_meta.meta_key = 'method_id' 
				AND order_item_meta.meta_value IN('" . implode("','", $services) . "') 
				" . ((!empty($dateRange)) ? "AND posts.post_date >= '" . $dateRange . "'" : '') . " 
				" . ((!empty($dateTo)) ? "AND posts.post_date <= '" . $dateTo . "'" : '') . " 
				" . (($status) ? "AND posts.post_status = '" . $status . "'" : '') . "
				ORDER BY order_id DESC";
		}
		error_log("\r\n[" . date("r") . "] Consulta manifiesto 1 :" . $orderSql, 3, str_replace('classes', 'log', plugin_dir_path(__FILE__)) . "/".date('Ymd').".log");

		$results = $wpdb->get_col($orderSql);
       
	    $items = array();

        foreach ($results as $orderId) {
            $order = new WC_Order($orderId);

            $bultos = 1;

            $sqlbultos = "SELECT meta_value FROM $wpdb->postmeta WHERE post_id = " . $orderId . " and meta_key = 'gls_bultos'";
            $resbultos = $wpdb->get_results($sqlbultos);

            if (!empty($resbultos[0])) {
                $bultos = $resbultos[0]->meta_value;
            }
            $sql = "SELECT meta_value FROM $wpdb->postmeta WHERE post_id = " . $orderId . " and meta_key = 'codbarras'";
            $rs = $wpdb->get_results($sql);
            $gen = 0;
            if (!empty($rs)) {
                foreach ($rs as $r) {
                    if (!empty($r->meta_value)) {
                        $gen = $r->meta_value;
                    } else {
                        $gen = 1;
                    }
                }
            } else {
                $gen = 1;
            }
            if ($gen != 0 && $gen != 1) {
                $action = "";
                $items[] = array(
                    'codbarras' => 'Código GLS: '.$gen,
                    'customer' => 'Pedido: '.$orderId.'<br>'.
								  'Información de la entrega:<br>'.
								  $order->get_shipping_first_name() . ' ' . $order->get_shipping_last_name().'<br>'.
								  $order->get_shipping_address_1() . ' ' . $order->get_shipping_address_2().'<br>'.
								  $order->get_shipping_postcode() . ' - ' . $order->get_shipping_city().'<br>'.
								  $order->get_billing_phone(),
                    'precio' => 'Total: '.$order->get_total(),
                );
            }
        }

        $total_items = count($items);
		$this->found_data = array_slice($items, (($current_page - 1) * $per_page), $per_page);

        $this->set_pagination_args(array(
            'total_items' => $total_items,
            'per_page' => $per_page,
            'total_pages' => ceil($total_items / $per_page),
        ));
        $this->items = $this->found_data;
        $this->process_bulk_action();
    }

} //class

class GLS_Manifiestos2_List_Table extends WP_List_Table
{
    public $example_data = array();
    public $found_data = array();

    public function __construct()
    {
        global $status, $page;
        parent::__construct(array(
            'singular' => __('envío', 'woocommerce-gls-envios'),
            'plural' => __('envíos', 'woocommerce-gls-envios'),
            'ajax' => false,
        ));
        add_action('admin_head', array(&$this, 'admin_header'));
    }

    public function admin_header()
    {
        $page = (isset($_GET['page'])) ? esc_attr($_GET['page']) : false;
        if (
		'gls' != $page && 
		'gls-manifiestos-submenu-page' != $page && 
		'gls-pedidos-submenu-page' != $page && 
		'gls-manifiestos2-submenu-page' != $page) {
            return;
        }
        wp_enqueue_script('jquery-ui-timepicker-addon', 'https://cdnjs.cloudflare.com/ajax/libs/jquery-ui-timepicker-addon/1.6.3/jquery-ui-timepicker-addon.min.js', array());
        wp_enqueue_style('jquery-ui-timepicker-addon', 'https://cdnjs.cloudflare.com/ajax/libs/jquery-ui-timepicker-addon/1.6.3/jquery-ui-timepicker-addon.min.css', array());
    
        echo '<style type="text/css">';
        echo '.wp-list-table .column-codbarras { width: 10%;}';
        echo '.wp-list-table .column-orderid { width: 10%;}';
        echo '.wp-list-table .column-precio { width: 5%;}#wpfooter{display: none;}';
		echo '.extended .wp-list-table .column-codbarras { width: 30%;}';
        echo '.extended .wp-list-table .column-orderid { width: 60%;}';
        echo '.extended .wp-list-table .column-precio { width: 10%;}';
        echo '</style>';
    }

    public function no_items()
    {
        _e('No hay envios de GLS.');
    }

    public function column_default($item, $column_name)
    {
        switch ($column_name) {
            case 'orderid':
            case 'fecha_pedido':
                return $item[$column_name];
            default:
                return $item[$column_name];
        }
    }

    public function get_sortable_columns()
    {
        $sortable_columns = array(
            /*  'orderid'  => array('orderid',false),
        'fecha_pedido' => array('fecha_pedido',false) */
        );
        return $sortable_columns;
    }

    public function get_columns()
    {
        $columns = array(
            'cb' => '',
            'orderid' => __('Referencia', 'woocommerce-gls-envios'),
            'codbarras' => __('Cod. Barras', 'woocommerce-gls-envios'),
            'bultos' => __('Bultos', 'woocommerce-gls-envios'),
            'precio' => __('Total', 'woocommerce-gls-envios'),
            'customer' => __('Info entrega', 'woocommerce-gls-envios'),
            'address' => __('Dirección', 'woocommerce-gls-envios'),
            'cp' => __('CP - Ciudad', 'woocommerce-gls-envios'),
            'phone' => __('Telefono', 'woocommerce-gls-envios'),
        );
        return $columns;
    }

    public function usort_reorder($a, $b)
    {
        $orderby = (!empty($_GET['orderby'])) ? $_GET['orderby'] : 'orderid';
        $order = (!empty($_GET['order'])) ? $_GET['order'] : 'desc';
        $result = strcmp($a[$orderby], $b[$orderby]);
        return ($order === 'asc') ? $result : -$result;
    }

    public function get_bulk_actions()
    {
        $actions = array(
            'csv' => 'CSV-EXCEL',
			//'pdf' => 'PDF',
            'print' => 'IMPRIMIR',
        );
        return $actions;
    }

    public function process_bulk_action()
    {
        if (empty($_REQUEST['doaction'])) {
            return;
        }
        if (isset($_REQUEST['_wpnonce']) && !empty($_REQUEST['_wpnonce'])) {
            $nonce = filter_input(INPUT_POST, '_wpnonce', FILTER_SANITIZE_STRING);
            $action = 'bulk-' . $this->_args['plural'];
            if (!wp_verify_nonce($nonce, $action)) {
                wp_die('Error de seguridad');
            }

        }
        $action = $this->current_action();
        switch ($action) {
            case 'csv':
                ob_end_clean();
                $csv = '"MANIFIESTO DE CARGA GLS";' . "\n";
                $bultos = 0;
                if (!empty($this->items)) {
					foreach ($this->items as $item) {
						unset($item['ID']);
						unset($item['orderid']);
						unset($item['precio']);
						$csv .= '"' . implode('";"', $item) . '"' . "\n";
						$bultos += $item['bultos'];
					}
                }
                $csv .= '"";"Total bultos:";"' . $bultos . '"';
                header("Content-Disposition: attachment; filename=manifiestos.csv");
                header("Pragma: no-cache");
                header("Expires: 0");
                header("Content-type: application/x-msdownload", true, 200);
                echo chr(239) . chr(187) . chr(191) . $csv;
                die();
                break;
            case 'pdf':
                wp_die('pdf');
                break;
            case 'print':
                $bultos = 0;
                if (!empty($_REQUEST['orderid'])) {
                    foreach ($_REQUEST['orderid'] as $orderid) {
                        foreach ($this->items as $item) {
                            if ($item['ID'] == $orderid) {
                                $bultos += $item['bultos'];
                            }
                        }
                    }
                }
				$logoUrl = plugins_url('../images/logo-gls.png', __FILE__);
                ?>
				<script>
					jQuery(window).load(function(){
						jQuery( ".toggle-row" ).remove(  );
						jQuery( ".check-column input" ).remove(  );
						var divToPrint=document.getElementById("printTable").getElementsByTagName('table')[0];
						newWin= window.open("");
						newWin.document.write('<h1><img style="height: 40px;" src="<?php echo $logoUrl; ?>">&nbsp;<?=__('Manifiesto de carga', 'woocommerce-gls-envios')?></h1><h2><?php echo date('d/m/Y')?></h2>'+divToPrint.outerHTML+'<p><?=__('Total bultos', 'woocommerce-gls-envios')?>: <?php echo $bultos; ?></p>');
						newWin.print();
						newWin.close();
					});
				</script>
				<?php
				break;
            default:
                return;
                break;
        }
        return;
    }

    public function display_tablenav($which)
    {
        if ($which == 'top') {
            $uri = plugins_url('') . '/woocommerce-gls-envios/';
            include plugin_dir_path(dirname(__FILE__)) . 'templates/views/manifest2-nav.php';
        }
    }

    public function extra_tablenav($which)
    {
        //parent::extra_tablenav( $which );
        if ($which == 'top') {
            do_action('restrict_manage_posts', 'shop_order', 'top');
        }

    }
    public function column_cb($item)
    {
        return sprintf(
            '<input type="hidden" name="orderid[]" value="%s" />', $item['ID']
        );
    }

    public function prepare_manifiestos()
    {
        global $wpdb;
		
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);
        usort($this->example_data, array(&$this, 'usort_reorder'));
        $per_page = 50;
        $current_page = $this->get_pagenum();

        $orderby = (!empty($_GET['orderby'])) ? $_GET['orderby'] : 'fecha_pedido';
        $order = (!empty($_GET['order'])) ? $_GET['order'] : 'desc';
        $paged = isset($_REQUEST['paged']) ? max(0, intval($_REQUEST['paged']) - 1) : 0;

        $services = WC_GLS_Shipping_Method::getServices(true);

        $dateRange = empty($_REQUEST['glsDateRange']) ? date('Y-m-d', time() - 86400) : $_REQUEST['glsDateRange'];
        $dateTo = empty($_REQUEST['glsDateTo']) ? '' : $_REQUEST['glsDateTo'];
        $status = (!empty($_REQUEST['post_status']) && $_REQUEST['post_status'] != '-1') ? $_REQUEST['post_status'] : false;

		if ( !class_exists( \Automattic\WooCommerce\Internal\DataStores\Orders\CustomOrdersTableController::class ) ){
			$post_type = 'shop_order';
		} else {
			$post_type = 'shop_order_placehold';
		}

		$openCarrier = get_option('gls_opencarrier');
		if ($openCarrier){
			$orderSql = "SELECT order_items.order_id 
				FROM {$wpdb->prefix}woocommerce_order_items as order_items 
				LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id 
				LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID 
				WHERE posts.post_type IN ('shop_order','shop_order_placehold')
				AND order_items.order_item_type = 'shipping' 
				AND order_item_meta.meta_key = 'method_id' 
				" . ((!empty($dateRange)) ? "AND posts.post_date >= '" . $dateRange . "'" : '') . " 
				" . ((!empty($dateTo)) ? "AND posts.post_date <= '" . $dateTo . "'" : '') . " 
				" . (($status) ? "AND posts.post_status = '" . $status . "'" : '') . "
				ORDER BY order_id DESC";
		} else {
			$orderSql = "SELECT order_items.order_id 
				FROM {$wpdb->prefix}woocommerce_order_items as order_items 
				LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id 
				LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID 
				WHERE posts.post_type IN ('shop_order','shop_order_placehold')
				AND order_items.order_item_type = 'shipping' 
				AND order_item_meta.meta_key = 'method_id' 
				AND order_item_meta.meta_value IN('" . implode("','", $services) . "') 
				" . ((!empty($dateRange)) ? "AND posts.post_date >= '" . $dateRange . "'" : '') . " 
				" . ((!empty($dateTo)) ? "AND posts.post_date <= '" . $dateTo . "'" : '') . " 
				" . (($status) ? "AND posts.post_status = '" . $status . "'" : '') . "
				ORDER BY order_id DESC";
		}
		error_log("\r\n[" . date("r") . "] Consulta manifiesto 2 :" . $orderSql, 3, str_replace('classes', 'log', plugin_dir_path(__FILE__)) . "/".date('Ymd').".log");

		$results = $wpdb->get_col($orderSql);
		
        $items = array();

        foreach ($results as $orderId) {
            $order = new WC_Order($orderId);

            $bultos = 1;

            $sqlbultos = "SELECT meta_value FROM $wpdb->postmeta WHERE post_id = " . $orderId . " and meta_key = 'gls_bultos'";
            $resbultos = $wpdb->get_results($sqlbultos);

            if (!empty($resbultos[0])) {
                $bultos = $resbultos[0]->meta_value;
            }
            $sql = "SELECT meta_value FROM $wpdb->postmeta WHERE post_id = " . $orderId . " and meta_key = 'codbarras'";
            $rs = $wpdb->get_results($sql);
            $gen = 0;
            if (!empty($rs)) {
                foreach ($rs as $r) {
                    if (!empty($r->meta_value)) {
                        $gen = $r->meta_value;
                    } else {
                        $gen = 1;
                    }
                }
            } else {
                $gen = 1;
            }
            if ($gen != 0 && $gen != 1) {
                $action = "";
                $items[] = array(
                    'ID' => $orderId,
                    'orderid' => $orderId,
                    'codbarras' => $gen,
                    'bultos' => $bultos,
                    'precio' => $order->get_total(),
                    'customer' => $order->get_shipping_first_name() . ' ' . $order->get_shipping_last_name(),
                    'address' => $order->get_shipping_address_1() . ' ' . $order->get_shipping_address_2(),
                    'cp' => $order->get_shipping_postcode() . ' ' . $order->get_shipping_city(),
                    'phone' => $order->get_billing_phone(),
                );
            }
        }

        $this->found_data = array_slice($items, (($current_page - 1) * $per_page), $per_page);
        
		$total_items = count($items);

        $this->set_pagination_args(array(
            'total_items' => $total_items,
            'per_page' => $per_page,
            'total_pages' => ceil($total_items / $per_page),
        ));
        $this->items = $this->found_data;
        $this->process_bulk_action();
    }

} //class

class glsDateRange
{

    public function __construct()
    {
        add_action('admin_enqueue_scripts', array($this, 'jqueryui'));
        add_action('restrict_manage_posts', array($this, 'form'));
    }

    public function jqueryui()
    {
        wp_enqueue_style('jquery-ui', '//code.jquery.com/ui/1.11.4/themes/smoothness/jquery-ui.min.css');
        wp_enqueue_script('jquery-ui-datepicker');
    }

    public function form()
    {
        global $typenow;
        global $wp_query;
        $screen = get_current_screen();
        $statuses = wc_get_order_statuses();
        if (
            $screen->id != 'toplevel_page_gls' &&
            $screen->id != 'gls_page_gls-manifiestos-submenu-page' &&
            $screen->id != 'admin_page_gls-manifiestos2-submenu-page' &&
            $screen->id != 'woocommerce_page_gls-pedidos-submenu-page' &&
            $screen->id != 'woocommerce_page_gls-manifiestos-submenu-page'
        ) {
            return;
        }

        $from = (isset($_REQUEST['glsDateRange']) && $_REQUEST['glsDateRange']) ? $_REQUEST['glsDateRange'] : '';
        $to = (isset($_REQUEST['glsDateTo']) && $_REQUEST['glsDateTo']) ? $_REQUEST['glsDateTo'] : '';
        $poststatus = (isset($_REQUEST['post_status']) && $_REQUEST['post_status'] != '-1') ? $_REQUEST['post_status'] : '';
        echo '<style>
			input[name="glsDateRange"], input[name="glsDateTo"]{
				line-height: 28px;
				height: 28px;
				margin: 0;
				width:125px;
			}
			</style>';
		//if ($screen->id == 'toplevel_page_gls'){
			echo '<select name="post_status" id="post_status-selector-top">
				<option value="-1">Estado</option>';
				foreach ($statuses as $vstatus => $lstatus) {
					echo '<option value="' . $vstatus . '"' . (($poststatus == $vstatus) ? ' selected="selected"' : '') . '>' . $lstatus . '</option>';
				}
			echo '</select>';
		//}
		echo '<input type="text" name="glsDateRange" placeholder="' . __('Desde', 'woocommerce-gls-envios') . '" value="' . $from . '" autocomplete="off" />
		<input type="text" name="glsDateTo" placeholder="' . __('Hasta', 'woocommerce-gls-envios') . '" value="' . $to . '" autocomplete="off" />
		<button type="submit" name="glsDateRange" class="button" value="' . date('Y-m-d H:i:s', mktime(0, 0, 0, date('m'), date('d'), date('Y'))) . '">' . __('Hoy', 'woocommerce-gls-envios') . '</button>
		<button type="submit" name="glsDateRange" class="button" value="' . date('Y-m-d H:i:s', strtotime('This Week')) . '">' . __('Semana', 'woocommerce-gls-envios') . '</button>
		<button type="submit" name="glsDateRange" class="button" value="' . date('Y-m-d H:i:s', mktime(0, 0, 0, date('m'), 1, date('Y'))) . '">' . __('Mes', 'woocommerce-gls-envios') . '</button>
		<button type="reset" name="filter_reset" class="button" onclick="resetForm();">' . __('Limpiar', 'woocommerce-gls-envios') . '</button>
		<input type="submit" name="filter_action" id="post-query-submit" class="button" value="' . __('Filtrar', 'woocommerce-gls-envios') . '">
		<script>
		jQuery( function($) {
			var from = $(\'input[name="glsDateRange"]\'),
			    to = $(\'input[name="glsDateTo"]\');

			$( \'input[name="glsDateRange"], input[name="glsDateTo"]\' ).datetimepicker({dateFormat : "yy-mm-dd"});
   			from.on( \'change\', function() {
				to.datetimepicker( \'option\', \'minDate\', from.val() );
			});

			to.on( \'change\', function() {
				from.datetimepicker( \'option\', \'maxDate\', to.val() );
			});
			$(\'#doaction, #doaction2\').click(function(event){
				if ($(\'#bulk-action-selector-top\').val() == \'printtag\' || $(\'#bulk-action-selector-bottom\').val() == \'printtag\'){
					$(\'#wpbody-content .tablenav.top\').hide();
					$(\'#wpbody-content .wp-list-table.envios\').hide();
					$(\'#wpbody-content .info-gls\').append(\'<div class="updated notice"><p>' . __('Sus etiquetas de transporte se están generando. Pulse el siguiente enlace para refrescar el estado de los pedidos GLS una vez las haya impreso.', 'woocommerce-gls-envios') . '</p><p><a href="javascript:location.reload(true);">' . __('Refrescar', 'woocommerce-gls-envios') . '</a></p></div>\');
				}
			});
		});
		function resetForm(){
			var from = jQuery(\'input[name="glsDateRange"]\'),
			    to = jQuery(\'input[name="glsDateTo"]\');
				from.val(\'\');
				to.val(\'\');
				jQuery(\'#post-query-submit\').click();
		}
		</script>';
    }

}
new glsDateRange();
