<?php

/**
 * Public functions
 */

/**
 * Show the template part
 */
if (!function_exists('wcdn_get_template')) {
    function wcdn_get_template($name)
    {
        global $wcdn;
        $wcdn->print->get_template($name);
    }
}

/**
 * Show template  url
 */
if (!function_exists('wcdn_stylesheet_url')) {
    function wcdn_stylesheet_url($name)
    {
        global $wcdn;
        echo $wcdn->print->get_template_url($name);
    }
}

/**
 * Show the template title depending on type
 */
if (!function_exists('wcdn_template_title')) {
    function wcdn_template_title()
    {
        global $wcdn;
        if ($wcdn->print->template_type == 'invoice') {
            echo __('Factura', 'woocommerce-gls-envios');
        } else {
            echo __('Albarán', 'woocommerce-gls-envios');
        }
    }
}

/**
 * Show logo html
 */
if (!function_exists('wcdn_gls_company_logo')) {
    function wcdn_gls_company_logo()
    {
        global $wcdn;
        $attachment_id = $wcdn->settings->get_setting('company_logo_image_id');
        $company = $wcdn->settings->get_setting('custom_company_name');
        if ($attachment_id) {
            $attachment_src = wp_get_attachment_image_src($attachment_id, 'full', false);
            ?>
			<img src="<?php echo $attachment_src[0]; ?>" width="<?php echo $attachment_src[1]; ?>" height="<?php echo $attachment_src[2]; ?>" alt="<?php echo esc_attr($company); ?>"/>
			<?php
}
        return;
    }
}

/**
 * Return default title name of Delivery Note
 */
if (!function_exists('wcdn_gls_company_name')) {
    function wcdn_gls_company_name()
    {
        global $wcdn;
        $name = trim($wcdn->settings->get_setting('custom_company_name'));
        if (!empty($name)) {
            echo wpautop(wptexturize($name));
        } else {
            echo get_bloginfo('name');
        }
    }
}

/**
 * Return shop/company info if provided
 */
if (!function_exists('wcdn_gls_company_info')) {
    function wcdn_gls_company_info()
    {
        global $wcdn;
        echo wpautop(wptexturize($wcdn->settings->get_setting('company_address')));
    }
}

/**
 * Show billing phone
 */
if (!function_exists('wcdn_billing_phone')) {
    function wcdn_billing_phone()
    {
        global $wcdn;
        echo $wcdn->print->get_order()->billing_phone;
    }
}

/**
 * Show billing email
 */
if (!function_exists('wcdn_billing_email')) {
    function wcdn_billing_email()
    {
        global $wcdn;
        echo $wcdn->print->get_order()->billing_email;
    }
}

/**
 * Show billing address
 */
if (!function_exists('wcdn_billing_address')) {
    function wcdn_billing_address()
    {
        global $wcdn;
        $address = $wcdn->print->get_order()->get_formatted_billing_address();
        if (!$address) {
            $address = _e('N/A', 'woocommerce');
        }
        echo $address;
    }
}

/**
 * Show shipping address
 */
if (!function_exists('wcdn_shipping_address')) {
    function wcdn_shipping_address()
    {
        global $wcdn;
        $address = $wcdn->print->get_order()->get_formatted_shipping_address();
        if (!$address) {
            $address = _e('N/A', 'woocommerce');
        }
        echo $address;
    }
}

/**
 * Get order
 */
if (!function_exists('wcdn_gls_get_order')) {
    function wcdn_gls_get_order($order_id = null)
    {
        global $wcdn;
        return $wcdn->print->get_order($order_id);
    }
}

/**
 * Get order custom field
 */
if (!function_exists('wcdn_get_order_custom_field')) {
    function wcdn_get_order_custom_field($field)
    {
        global $wcdn;
        return $wcdn->print->get_order_field($field);
    }
}

/**
 * Show order number
 */
if (!function_exists('wcdn_order_number')) {
    function wcdn_order_number()
    {
        global $wcdn;

        // Trim the hash to have a clean number but still
        // support any filters that were applied before.
        $order_number = ltrim($wcdn->print->get_order()->get_order_number(), '#');
        echo $order_number;
    }
}

/**
 * Show the order date
 */
if (!function_exists('wcdn_order_date')) {
    function wcdn_order_date()
    {
        global $wcdn;
        $order = $wcdn->print->get_order();
        echo date_i18n(get_option('date_format'), strtotime($order->order_date));
    }
}

/**
 * Return the order items
 */
if (!function_exists('wcdn_get_order_items')) {
    function wcdn_get_order_items()
    {
        global $wcdn;
        return $wcdn->print->get_order_items();
    }
}

/**
 * Return the order totals listing
 */
if (!function_exists('wcdn_get_order_totals')) {
    function wcdn_get_order_totals()
    {
        global $wcdn;

        // get totals and remove the semicolon
        $totals = $wcdn->print->get_order()->get_order_item_totals();

        // remove the colon for every label
        foreach ($totals as $key => $total) {
            $label = $total['label'];
            $colon = strrpos($label, ':');
            if ($colon !== false) {
                $label = substr_replace($label, '', $colon, 1);
            }
            $totals[$key]['label'] = $label;
        }

        return $totals;
    }
}

/**
 * Return has shipping notes
 */
if (!function_exists('wcdn_get_shipping_notes')) {
    function wcdn_get_shipping_notes()
    {
        global $wcdn;
        return wpautop(wptexturize($wcdn->print->get_order()->customer_note));
    }
}

/**
 * Show shipping notes
 */
if (!function_exists('wcdn_shipping_notes')) {
    function wcdn_shipping_notes()
    {
        global $wcdn;
        echo wcdn_get_shipping_notes();
    }
}

/**
 * Return personal notes, season greetings etc.
 */
if (!function_exists('wcdn_gls_get_personal_notes')) {
    function wcdn_gls_get_personal_notes()
    {
        global $wcdn;
        return wpautop(wptexturize($wcdn->settings->get_setting('personal_notes')));
    }
}

/**
 * Show personal notes, season greetings etc.
 */
if (!function_exists('wcdn_gls_personal_notes')) {
    function wcdn_gls_personal_notes()
    {
        global $wcdn;
        echo wcdn_get_personal_notes();
    }
}

/**
 * Return policy for returns
 */
if (!function_exists('wcdn_gls_get_policies_conditions')) {
    function wcdn_gls_get_policies_conditions()
    {
        global $wcdn;
        return wpautop(wptexturize($wcdn->settings->get_setting('policies_conditions')));
    }
}

/**
 * Show policy for returns
 */
if (!function_exists('wcdn_gls_policies_conditions')) {
    function wcdn_gls_policies_conditions()
    {
        global $wcdn;
        echo wcdn_get_policies_conditions();
    }
}

/**
 * Return shop/company footer imprint, copyright etc.
 */
if (!function_exists('wcdn_get_footer_imprint')) {
    function wcdn_get_footer_imprint()
    {
        global $wcdn;
        return wpautop(wptexturize($wcdn->settings->get_setting('footer_imprint')));
    }
}

/**
 * Show shop/company footer imprint, copyright etc.
 */
if (!function_exists('wcdn_footer_imprint')) {
    function wcdn_footer_imprint()
    {
        global $wcdn;
        echo wcdn_get_footer_imprint();
    }
}

/**
 * register_gls_submenu_page
 */
if (!function_exists('register_gls_submenu_page')) {    
    function register_gls_submenu_page()
    {        
        global $glsTable;
        global $glsMTable;
        global $glsMTable2;
        $glsTable = new GLS_List_Table();
        $glsMTable = new GLS_Manifiestos_List_Table();
        $glsMTable2 = new GLS_Manifiestos2_List_Table();
        $icon_url = null;
        add_menu_page(__('GLS', 'woocommerce-gls-envios'), __('GLS', 'woocommerce-gls-envios'), 'manage_options', 'gls', 'gls_submenu_page_callback', $icon_url);
        add_submenu_page('gls', __('GLS Pedidos', 'woocommerce-gls-envios'), __('GLS Pedidos', 'woocommerce-gls-envios'), 'manage_options', 'gls', 'gls_submenu_page_callback');
        add_submenu_page('gls', __('GLS Manifiestos', 'woocommerce-gls-envios'), __('GLS Manifiestos', 'woocommerce-gls-envios'), 'manage_options', 'gls-manifiestos-submenu-page', 'gls_manifiestos_page_callback');
        add_submenu_page('gls-manifiestos-submenu-page', __('GLS Manifiestos Agrupado', 'woocommerce-gls-envios'), __('GLS Manifiestos Agrupado', 'woocommerce-gls-envios'), 'manage_options', 'gls-manifiestos2-submenu-page', 'gls_manifiestos2_page_callback');
        add_submenu_page('gls', __('GLS Tarifas', 'woocommerce-gls-envios'), __('GLS Tarifas', 'woocommerce-gls-envios'), 'manage_options', 'gls-tarifas-submenu-page', 'gls_tarifas_page_callback');
        add_submenu_page('gls', __('GLS Configuración', 'woocommerce-gls-envios'), __('GLS Configuración', 'woocommerce-gls-envios'), 'manage_options', 'gls-settings-submenu-page', 'gls_settings_page_callback');
    }
}

/**
 * gls_submenu_page_callback
 */
if (!function_exists('gls_submenu_page_callback')) {
    function gls_submenu_page_callback()
    {
        global $glsTable;
        $glsTable->prepare_items();
        include dirname(__FILE__) . '/templates/views/menu-page.php';
    }
}

/**
 * gls_manifiestos_page_callback
 */
if (!function_exists('gls_manifiestos_page_callback')) {
    function gls_manifiestos_page_callback()
    {
        global $glsMTable;
        $glsMTable->prepare_manifiestos();
        include dirname(__FILE__) . '/templates/views/manifiestos-page.php';
    }
}

/**
 * gls_manifiestos2_page_callback
 */
if (!function_exists('gls_manifiestos2_page_callback')) {
    function gls_manifiestos2_page_callback()
    {
        global $glsMTable2;
        $glsMTable2->prepare_manifiestos();
        include dirname(__FILE__) . '/templates/views/manifiestos2-page.php';
    }
}

/**
 * Install tables to manage services and ranges
 */
if (!function_exists('gls_install')) {
    function gls_install()
    {
		if ( is_multisite() ) { 
			foreach (get_sites(['fields'=>'ids']) as $blog_id) {
				switch_to_blog($blog_id);
				gls_install_script();
				restore_current_blog();
			}
		} else {
			gls_install_script();
		}
    }
}

if (!function_exists('gls_install_script')) {
    function gls_install_script()
    {
		global $wpdb;
		$charset_collate = $wpdb->get_charset_collate();

		$table = $wpdb->prefix . 'gls_services';
		$sql_a = "CREATE TABLE IF NOT EXISTS `$table` (
			`zone_id` INT(11) NOT NULL,
			`service` VARCHAR(128) DEFAULT '' NOT NULL,
			`type` TINYINT(1) DEFAULT 0 NOT NULL,
			`role` VARCHAR(128) DEFAULT '' NOT NULL,
			`enabled` TINYINT(1) DEFAULT 0 NOT NULL,            
			PRIMARY KEY  (`zone_id`,`service`,`type`,`role`)
		) $charset_collate;";

		$table = $wpdb->prefix . 'gls_services_cost';
		$sql_b = "CREATE TABLE IF NOT EXISTS `$table` (
			`zone_id` INT(11) NOT NULL,
			`service` VARCHAR(128) DEFAULT '' NOT NULL,
			`role` VARCHAR(128) DEFAULT '' NOT NULL,
			`type` TINYINT(1) DEFAULT 0 NOT NULL, # 0 amount 1 weight
			`min` DECIMAL(10,2) DEFAULT 0 NOT NULL,
			`max` DECIMAL(10,2) DEFAULT 0 NOT NULL,
			`cost` DECIMAL(10,2) DEFAULT 0 NOT NULL,
			`extra` DECIMAL(10,2) DEFAULT 0 NOT NULL
		) $charset_collate;";

		require_once ABSPATH . 'wp-admin/includes/upgrade.php';
		dbDelta($sql_a);
		dbDelta($sql_b);

		add_option('gls_order_state_sended', 'wc-sended');
		add_option('gls_order_state_delivered', 'wc-delivered');
		add_option('gls_order_state_in_transit', 'wc-in-transit');

		//gls_check_client_data();
		
		add_filter('cron_schedules', 'gls_init_schedule');
		wp_clear_scheduled_hook('gls_cron_hook');
		if (! wp_next_scheduled ( 'gls_cron_hook' )) {
			wp_schedule_event(time(), 'gls_cron', 'gls_cron_hook');
		}

        gls_check_options();

	}
}

if (!function_exists('gls_check_options')) {
    function gls_check_options()
    {
        $glsOptions = get_option('gls_envios_options');
        $oldOptionGuid = get_option('gls_guid');
        if (empty($glsOptions['gls_guid']) && !empty($oldOptionGuid)){
			
			$glsOptionsNew = array(
				'gls_guid' => get_option('gls_guid'),
				'gls_wsdl' => get_option('gls_wsdl'),
				'gls_total_taxes' => get_option('gls_total_taxes'),
				'gls_weight' => get_option('gls_weight'),
				'gls_packages_mode' => get_option('gls_packages_mode'),
				'gls_packages' => get_option('gls_packages'),
				'gls_items' => get_option('gls_items'),
				'gls_return' => get_option('gls_return'),
				'gls_rcs' => get_option('gls_rcs'),
				'gls_origin' => get_option('gls_origin'),
				'gls_insured' => get_option('gls_insured'),
				'gls_incoterm' => get_option('gls_incoterm'),
				'gls_sender_name' => get_option('gls_sender_name'),
				'gls_sender_address' => get_option('gls_sender_address'),
				'gls_sender_postal_code' => get_option('gls_sender_postal_code'),
				'gls_sender_city' => get_option('gls_sender_city'),
				'gls_sender_country' => get_option('gls_sender_country'),
				'gls_order_state_sended_enabled' => get_option('gls_order_state_sended_enabled'),
				'gls_order_state_sended' => get_option('gls_order_state_sended'),
				'gls_order_state_delivered_enabled' => get_option('gls_order_state_delivered_enabled'),
				'gls_order_state_delivered' => get_option('gls_order_state_delivered'),
				'gls_order_state_in_transit_enabled' => get_option('gls_order_state_in_transit_enabled'),
				'gls_order_state_in_transit' => get_option('gls_order_state_in_transit'),
				'gls_tracking_note' => get_option('gls_tracking_note'),
				'gls_tracking_note_txt' => get_option('gls_tracking_note_txt'),
				'gls_tipo_etiqueta' => get_option('gls_tipo_etiqueta'),
				'gls_apli4' => get_option('gls_apli4')
			);
			
            if (FALSE === update_option('gls_envios_options',$glsOptionsNew)) add_option('gls_envios_options',$glsOptionsNew);
        }
    }
}

/* if (!function_exists('gls_oldoptions_message')) {
    function gls_oldoptions_message() {
        if (get_transient('gls_oldoptions_message')) {
            ?>
            <div class="notice notice-success is-dismissible">
                <h3>GLS Envios</h3>
                <p><?php _e('¿Recuperar la configuración de versones anteriores del plugin?', 'woocommerce-gls-envios'); ?></p>
                <p><a href="<?php echo admin_url('admin.php?page=gls-settings-submenu-page&restore=1'); ?>" class="button button-primary"><?php _e('Recuperar', 'woocommerce-gls-envios'); ?></a></p>
            </div>
            <?php
            delete_transient('gls_oldoptions_message');
        }
    }
} */

/**
 * Unistall tables to manage services and ranges
 */
if (!function_exists('gls_uninstall')) {
    function gls_uninstall()
    {
       	if ( is_multisite() ) { 
			foreach (get_sites(['fields'=>'ids']) as $blog_id) {
				switch_to_blog($blog_id);
				gls_uninstall_script();
				restore_current_blog();
			}
		} else {
			gls_uninstall_script();
		}
    }
}

if (!function_exists('gls_uninstall_script')) {
    function gls_uninstall_script()
    {
        global $wpdb;
        $table = $wpdb->prefix . 'gls_services';
        $sql = "DROP TABLE IF EXISTS `$table`";
        $wpdb->query($sql);
        $table = $wpdb->prefix . 'gls_services_cost';
        $sql = "DROP TABLE IF EXISTS `$table`";
        $wpdb->query($sql);
        delete_option('gls_order_state_sended');
        delete_option('gls_order_state_delivered');
        delete_option('gls_order_state_in_transit');
        wp_clear_scheduled_hook('gls_cron_hook');
    }
}

/**
 * Deactivation function
 */
if (!function_exists('gls_deactivate')) {
    function gls_deactivate()
    {
		if ( is_multisite() ) { 
			foreach (get_sites(['fields'=>'ids']) as $blog_id) {
				switch_to_blog($blog_id);
				wp_clear_scheduled_hook('gls_cron_hook');
				restore_current_blog();
			}
		} else {
			wp_clear_scheduled_hook('gls_cron_hook');
		}
    }
}

if (!function_exists('gls_check_client_data')) {
	function gls_check_client_data(){
		global $woocommerce;
		
		$url = "https://ecommodules.gls-spain.es/api/ecommerce/get";
		$GLSEnvios = new WooCommerce_Gls_Envios();
		$fields = [
			'guid' => GLS_Settings::get_guid(),
			'cms' => 'WooCommerce',
			'cms_version' => $woocommerce->version,
			'plugin_version' => $GLSEnvios->version
		];
		$postdata = http_build_query($fields);
		
		$ch = curl_init( $url );
		curl_setopt( $ch, CURLOPT_POST, 1);
		curl_setopt( $ch, CURLOPT_POSTFIELDS, $postdata);
		curl_setopt( $ch, CURLOPT_FOLLOWLOCATION, 1);
		curl_setopt( $ch, CURLOPT_HEADER, 0);
		curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1);

		$response = curl_exec( $ch );
		if (!$response){
			error_log("\r\n[" . date("r") . "] " . 'Error cURL', 3, plugin_dir_path(__FILE__) . "/log/".date('Ymd').".log");
			error_log("\r\n[" . date("r") . "] " . $postdata, 3, plugin_dir_path(__FILE__) . "/log/".date('Ymd').".log");
			$responseCode = curl_getinfo($ch, CURLINFO_HTTP_CODE );
			error_log("\r\n[" . date("r") . "] " . $responseCode, 3, plugin_dir_path(__FILE__) . "/log/".date('Ymd').".log");
            $errorCode = curl_error($ch);
			error_log("\r\n[" . date("r") . "] " . $errorCode, 3, plugin_dir_path(__FILE__) . "/log/".date('Ymd').".log");
		} else {
			$jsonResponse = json_decode($response);
			error_log("\r\n[" . date("r") . "] " . print_r($jsonResponse, true), 3, plugin_dir_path(__FILE__) . "/log/".date('Ymd').".log");
			$mulEbp = $jsonResponse->excepciones->mulEbp;
			if (FALSE === get_option('gls_mulebp') && FALSE === update_option('gls_mulebp',$mulEbp)) { add_option('gls_mulebp',$mulEbp);} else {update_option('gls_mulebp',$mulEbp);}
			$openCarrier = $jsonResponse->excepciones->openCarrier;
			if (FALSE === get_option('gls_opencarrier') && FALSE === update_option('gls_opencarrier',$openCarrier)) { add_option('gls_opencarrier',$openCarrier);} else {update_option('gls_opencarrier',$openCarrier);}
			$wooMassive = $jsonResponse->excepciones->wooMassive;
			if (FALSE === get_option('gls_woomassive') && FALSE === update_option('gls_woomassive',$wooMassive)) { add_option('gls_woomassive',$wooMassive);} else {update_option('gls_woomassive',$wooMassive);}
			$bpESPT = $jsonResponse->excepciones->bpESPT;
			if (FALSE === get_option('gls_bpespt') && FALSE === update_option('gls_bpespt',$bpESPT)) { add_option('gls_bpespt',$bpESPT);} else {update_option('gls_bpespt',$bpESPT);}
			$disableStateUpdate = $jsonResponse->excepciones->disableStateUpdate;
			if (FALSE === get_option('gls_disable_state_update') && FALSE === update_option('gls_disable_state_update',$disableStateUpdate)) { add_option('gls_disable_state_update',$disableStateUpdate);} else {update_option('gls_disable_state_update',$disableStateUpdate);}
			$updateStateFreq = $jsonResponse->globales->updateStateFreq;
			if (FALSE === get_option('gls_update_state_freq') && FALSE === update_option('gls_update_state_freq',$updateStateFreq)) { 
				add_option('gls_update_state_freq',$updateStateFreq);
			} else {
				if (get_option('gls_update_state_freq') != $updateStateFreq){
					update_option('gls_update_state_freq',$updateStateFreq);
					add_filter('cron_schedules', 'gls_init_schedule');
					wp_clear_scheduled_hook('gls_cron_hook');
					wp_schedule_event(time(), 'gls_cron', 'gls_cron_hook');
				}
			}
			$updateStateDays = $jsonResponse->globales->updateStateDays;
			if (FALSE === get_option('gls_update_state_days') && FALSE === update_option('gls_update_state_days',$updateStateDays)) { add_option('gls_update_state_days',$updateStateDays);} else {update_option('gls_update_state_days',$updateStateDays);}
			
			$sdiCountries = $jsonResponse->globales->paises;
			if (FALSE === get_option('gls_sdi_countries') && FALSE === update_option('gls_sdi_countries',$sdiCountries)) { add_option('gls_sdi_countries',$sdiCountries);} else {update_option('gls_sdi_countries',$sdiCountries);}
			
			
		}
		curl_close($ch);
	
	}
}
	




/**
 * Register order statuses
 */
if (!function_exists('gls_register_order_statuses')) {
    function gls_register_order_statuses($return = false)
    {
        $order_statuses = array(
            'wc-gls-sent' => array(
                'label' => __('GLS Enviado', 'woocommerce-gls-envios'),
                'public' => true,
                'show_in_admin_status_list' => true,
                'show_in_admin_all_list' => true,
                'exclude_from_search' => false,
                'label_count' => _n_noop('Enviado <span class="count">(%s)</span>', 'Enviado <span class="count">(%s)</span>'),
            ),
            'wc-gls-in-transit' => array(
                'label' => __('GLS En tránsito', 'woocommerce-gls-envios'),
                'public' => true,
                'show_in_admin_status_list' => true,
                'show_in_admin_all_list' => true,
                'exclude_from_search' => false,
                'label_count' => _n_noop('En tránsito <span class="count">(%s)</span>', 'En tránsito <span class="count">(%s)</span>'),
            ),
            'wc-gls-delivered' => array(
                'label' => __('GLS Entregado', 'woocommerce-gls-envios'),
                'public' => true,
                'show_in_admin_status_list' => true,
                'show_in_admin_all_list' => true,
                'exclude_from_search' => false,
                'label_count' => _n_noop('Entregado <span class="count">(%s)</span>', 'Entregado <span class="count">(%s)</span>'),
            ),
        );
        if ($return) {
            return $order_statuses;
        }
        foreach ($order_statuses as $key => $status) {
            register_post_status($key, $status);
        }
    }
}

/**
 * Register order statuses
 */
if (!function_exists('gls_add_order_statuses')) {
    function gls_add_order_statuses($order_statuses = array())
    {
        $new_order_statuses = gls_register_order_statuses(true);
        foreach ($new_order_statuses as $key => $status) {
            $order_statuses[$key] = $status['label'];
        }
        return $order_statuses;
    }
}

/**
 * Trigger on order status change
 */
if (!function_exists('gls_order_status_change')) {
    function gls_order_status_change($order_id, $checkout = null)
    {
        global $woocommerce, $wpdb;
        $mailer = $woocommerce->mailer();
        $sendmail = false;
        $glsOptions = get_option('gls_envios_options');
        $status_sended = $glsOptions[GLS_Settings::$prefix . 'order_state_sended'];
        $status_delivered = $glsOptions[GLS_Settings::$prefix . 'order_state_delivered'];
        $status_in_transit = $glsOptions[GLS_Settings::$prefix . 'order_state_in_transit'];        

        $order = wc_get_order( $order_id );
        $order_number = $order->get_order_number();
        $print = new WooCommerce_Gls_Envios_Print;        
        if (!in_array('wc-' . $order->get_status(), array($status_sended, $status_delivered, $status_in_transit))) {
            return;
        }
        if ($barcode = $print->existeEnvioGls($order_id)) {
	        $postal_code = $order->get_shipping_postcode();
        }
        if (empty($barcode) || empty($postal_code)) {
            return;
        }        
        $tracking_url = preg_replace(
            array('/\{tracking_number\}/', '/\{postal_code\}/'),
            array($barcode, $postal_code),
            GLS_Settings::$tracking_url
        );        
        if ('wc-' . $order->get_status() == $status_sended) {
            $subject = preg_replace(
                array('/\{order\}/'),
                array($order_number),
                isset($glsOptions[GLS_Settings::$prefix . 'order_state_sended_subject'])?$glsOptions[GLS_Settings::$prefix . 'order_state_sended_subject']: __('Su pedido {order} ha sido enviado', 'woocommerce-gls-envios')
            );
            $message_body = preg_replace(
                array('/\{tracking_url\}/', '/\{tracking_number\}/'),
                array($tracking_url, $barcode),
                isset($glsOptions[GLS_Settings::$prefix . 'order_state_sended_template'])?$glsOptions[GLS_Settings::$prefix . 'order_state_sended_template']: __('Puede acceder al seguimiento de su envío a través del siguiente enlace <a href="{tracking_url}" target="_blank">{tracking_number}</a>', 'woocommerce-gls-envios')
            );
            $sendmail = ((int)get_option(GLS_Settings::$prefix . 'order_state_sended_email_enabled') == 1);
        } else if ('wc-' . $order->get_status() == $status_delivered) {
            $subject = preg_replace(
                array('/\{order\}/'),
                array($order_number),
                isset($glsOptions[GLS_Settings::$prefix . 'order_state_delivered_subject'])?$glsOptions[GLS_Settings::$prefix . 'order_state_delivered_subject']: __('Su pedido {order} ha sido entregado', 'woocommerce-gls-envios')
            );
            $message_body = preg_replace(
                array('/\{tracking_url\}/', '/\{tracking_number\}/'),
                array($tracking_url, $barcode),
                isset($glsOptions[GLS_Settings::$prefix . 'order_state_delivered_email_template'])?$glsOptions[GLS_Settings::$prefix . 'order_state_delivered_email_template']: __('Puede acceder al seguimiento de su envío a través del siguiente enlace <a href="{tracking_url}" target="_blank">{tracking_number}</a>', 'woocommerce-gls-envios')
            );
            $sendmail = ((int)get_option(GLS_Settings::$prefix . 'order_state_delivered_email_enabled') == 1);
        } else if ('wc-' . $order->get_status() == $status_in_transit) {
            $subject = preg_replace(
                array('/\{order\}/'),
                array($order_number),
                isset($glsOptions[GLS_Settings::$prefix . 'order_state_in_transit_subject'])?$glsOptions[GLS_Settings::$prefix . 'order_state_in_transit_subject']: __('Su pedido {order} está en tránsito', 'woocommerce-gls-envios')
            );
            $message_body = preg_replace(
                array('/\{tracking_url\}/', '/\{tracking_number\}/'),
                array($tracking_url, $barcode),
                isset($glsOptions[GLS_Settings::$prefix . 'order_state_in_transit_template'])?$glsOptions[GLS_Settings::$prefix . 'order_state_in_transit_template']: __('Puede acceder al seguimiento de su envío a través del siguiente enlace <a href="{tracking_url}" target="_blank"{tracking_number}</a>', 'woocommerce-gls-envios')
            );
            $sendmail = ((int)get_option(GLS_Settings::$prefix . 'order_state_in_transit_email_enabled') == 1);
        }
        if ($sendmail) {
            $message = $mailer->wrap_message(
                $subject,
                str_replace('\"', '"', $message_body)
            );          
            $mailer->send(
                $order->get_billing_email(),
                $subject,
                $message
            );
        }
    }
}

/**
 * Display table with all services and configurable ranges
 */
if (!function_exists('gls_settings_page_callback')) {
    function gls_settings_page_callback()
    {
		gls_check_client_data();
        GLS_Settings::displaySettings();
    }
}

/**
 * Display table with all services and configurable ranges
 */
if (!function_exists('gls_tarifas_page_callback')) {
    function gls_tarifas_page_callback()
    {
        WC_GLS_Shipping_Method::displayTable();
    }
}

/**
 * Register new GLS shipping method
 */
if (!function_exists('add_gls_shipping_method')) {
    function add_gls_shipping_method($methods)
    {
		if (defined('DOING_AJAX') && DOING_AJAX && !empty($_POST['action']) && ($_POST['action'] == 'woocommerce_add_order_shipping' || $_POST['action'] == 'woocommerce_save_order_items')) { 
			$methods['gls10'] = 'WC_GLS_Shipping_Method_Gls10';
			$methods['gls14'] = 'WC_GLS_Shipping_Method_Gls14';
			$methods['gls24'] = 'WC_GLS_Shipping_Method_Gls24';
			$methods['buspar'] = 'WC_GLS_Shipping_Method_Buspar';
			$methods['economy'] = 'WC_GLS_Shipping_Method_Economy';
			$methods['eurobusinessparcel'] = 'WC_GLS_Shipping_Method_Ebp';
		} elseif ((!defined('DOING_AJAX')  && is_admin() && !empty($_GET['tab']) && $_GET['tab'] == 'checkout') /*|| (defined('DOING_AJAX') && DOING_AJAX && $_GET['wc-ajax'] == 'update_order_review')*/) {
			$methods['gls10'] = 'WC_GLS_Shipping_Method_Gls10';
			$methods['gls14'] = 'WC_GLS_Shipping_Method_Gls14';
			$methods['gls24'] = 'WC_GLS_Shipping_Method_Gls24';
			$methods['buspar'] = 'WC_GLS_Shipping_Method_Buspar';
			$methods['economy'] = 'WC_GLS_Shipping_Method_Economy';
			$methods['eurobusinessparcel'] = 'WC_GLS_Shipping_Method_Ebp';
			$methods['parcelshopgls'] = 'WC_GLS_Shipping_Method_Parcelshopgls';
			$methods['shopdelint'] = 'WC_GLS_Shipping_Method_Shopdelint';
		} else {
			$methods['gls_shipping_method'] = 'WC_GLS_Shipping_Method';
		}
        return $methods;
    }
}
if (!function_exists('gls_shipping_rate_method_id')) {
    function gls_shipping_rate_method_id($methodid, $method=null)
    {

 error_log("\r\n[" . date("r") . "] " . 'gls_shipping_rate_method_id: '.$methodid, 3, plugin_dir_path(__FILE__) . "/log/".date('Ymd').".log");
		if ($methodid == 'gls_shipping_method') {
			$chosen_shipping_methods_session = WC()->session->get( 'chosen_shipping_methods' );
			
 error_log("\r\n[" . date("r") . "] " . 'chosen_shipping_methods_session: '.print_r($chosen_shipping_methods_session,1), 3, plugin_dir_path(__FILE__) . "/log/".date('Ymd').".log");

			
			return $chosen_shipping_methods_session[0];
			switch($chosen_shipping_methods_session[0]){
				case 'gls10':
					return 'WC_GLS_Shipping_Method_Gls10';
					break;
				case 'gls14':
					return 'WC_GLS_Shipping_Method_Gls14';
					break;
				case 'gls24':
					return 'WC_GLS_Shipping_Method_Gls24';
					break;
				case 'buspar':
					return 'WC_GLS_Shipping_Method_Buspar';
					break;
				case 'economy':
					return 'WC_GLS_Shipping_Method_Economy';
					break;
				case 'eurobusinessparcel':
					return 'WC_GLS_Shipping_Method_Ebp';
					break;
				case 'parcelshopgls':
					return 'WC_GLS_Shipping_Method_Parcelshopgls';
					break;
				case 'shopdelint':
					return 'WC_GLS_Shipping_Method_Shopdelint';
					break;
			}
		}
		return $methodid;
    }
}


/**
 * Update order GLS shipping method
 */
if (!function_exists('gls_update_payment_method')) {
    function gls_update_payment_method($order_id)
    {
        if (isset(WC()->session->chosen_shipping_methods)) {
            $method_id = current(WC()->session->chosen_shipping_methods);
            if (!empty($method_id)) {
                $order = wc_get_order($order_id);
                foreach ($order->get_items('shipping') as $item_id => $item) {
                    if ($item->get_method_id() == 'gls_shipping_method') {
                        $item->set_method_id($method_id);
                        $item->save();
                    }
                }
            }
        }
    }
}

/**
 * Register javascript and css files and javascript variables
 */
if (!function_exists('gls_admin_enqueue_scripts')) {
    function gls_admin_enqueue_scripts()
    {
        wp_localize_script(
            'jquery',
            'pw_script_vars',
            array(
                'ajax_url' => admin_url('admin-ajax.php'),
            )
        );
		$GLSEnvios = new WooCommerce_Gls_Envios();
        wp_enqueue_script('jquery');
        wp_enqueue_script('wc-gls', plugins_url('/js/admin.js', __FILE__), array('jquery'), $GLSEnvios->version);        
        wp_enqueue_style('wc-gls', plugins_url('/css/style.css', __FILE__), false, $GLSEnvios->version);
        wp_enqueue_style('wc-gls-font', plugins_url('/css/gls-font.css', __FILE__), false, $GLSEnvios->version);
    }
}

/**
 * Register javascript and css files and javascript variables
 */
if (!function_exists('gls_enqueue_scripts')) {
    function gls_enqueue_scripts()
    {
		if(is_checkout()){
			$GLSEnvios = new WooCommerce_Gls_Envios();
			wp_enqueue_style('wc-gls-css', plugins_url('/css/front.css', __FILE__), false, $GLSEnvios->version);
			wp_enqueue_script( 'lity-script', plugins_url('js/lity.min.js',(__FILE__)), array( 'jquery' ), false, true );
			wp_enqueue_script('wc-gls-js', plugins_url('js/woocommerce.ajax.js',(__FILE__)), '', $GLSEnvios->version, true );
			wp_enqueue_style( 'lity-style', plugins_url('css/lity.min.css' ,(__FILE__)));
		}
    }
}

/**
 * Init schedule
 */
if (!function_exists('gls_init_schedule')) {
    function gls_init_schedule($schedules = array())
    {       
		$updateStateFreq = get_option('gls_update_state_freq');
		if (empty($updateStateFreq)) $updateStateFreq = 30;
		
        $schedules['gls_cron'] = array(
            'interval' => $updateStateFreq*60,
            'display' => __('Sincronización pedidos GLS', 'woocommerce-gls-envios'),
        ); 
        return $schedules;
    }
}

/**
 * Functions to cron job
 */
if (!function_exists('gls_cron_job')) {
    function gls_cron_job()
    {
       // if (!is_admin()) {
            WooCommerce_Gls_Wsdl::updateOrderStatuses();
       // }
    }
}

/**
 * AJAX METHOD used to enable, disable services for zones
 */
if (!function_exists('gls_check_service')) {
    function gls_check_service()
    {
        WC_GLS_Shipping_Method::checkService(
            $_REQUEST['zone_id'],
            $_REQUEST['role'],
            $_REQUEST['service'],
            $_REQUEST['type'],
            $_REQUEST['enabled']
        );
    }
}

/**
 * AJAX METHOD used to enable add a cost per range
 */
if (!function_exists('gls_range_add')) {
    function gls_range_add()
    {
        $resp = WC_GLS_Shipping_Method::rangeAdd(
            $_REQUEST['type'],
            $_REQUEST['zone_id'],
            $_REQUEST['role'],
            $_REQUEST['min'],
            $_REQUEST['max']
        );
        $json = wp_json_encode($resp);
        die($json);
    }
}

/**
 * AJAX METHOD used to delete a range
 */
if (!function_exists('gls_range_del')) {
    function gls_range_del()
    {
        $resp = WC_GLS_Shipping_Method::rangeDel(
            $_REQUEST['type'],
            $_REQUEST['zone_id'],
            $_REQUEST['role'],
            $_REQUEST['min'],
            $_REQUEST['max']
        );
        $json = wp_json_encode($resp);
        die($json);
    }
}

/**
 * AJAX METHOD used to retrive cost ranges for a zone
 */
if (!function_exists('gls_cost_update')) {
    function gls_cost_update()
    {
        $resp = WC_GLS_Shipping_Method::costUpdate(
            $_REQUEST['type'],
            $_REQUEST['zone_id'],
            $_REQUEST['role'],
            $_REQUEST['service'],
            $_REQUEST['min'],
            $_REQUEST['max'],
            $_REQUEST['extra'],
            $_REQUEST['cost']
        );
        $json = wp_json_encode($resp);
        die($json);
    }
}

/**
 * AJAX METHOD used to enable, disable services for zones
 */
if (!function_exists('call_gls_pickut')) {
    function call_gls_pickut()
    {
        if (!isset($_POST['send'])) {
            $last_time = get_option(GLS_Settings::$prefix . 'last_pickup');
            if (!empty($last_time)) {
                $day = date('Ymd');
                $last_day = date('Ymd', $last_time);
                $available = $day > $last_day ? true : false;
            } else {
                $available = true;
            }
            include dirname(__FILE__) . '/templates/views/request-pickup.php';
        } else {
            WooCommerce_Gls_Wsdl::callPickUp();            
            die('sended');
        }
        die();
    }
}



if (!function_exists('gls_show_parcels')) {
	function gls_show_parcels( $method, $index ) { 
			
		
		$chosen_methods = WC()->session->get( 'chosen_shipping_methods' );
		$chosen_shipping = $chosen_methods[0]; 

		if(is_checkout() && $method->id == 'parcelshopgls' && $chosen_shipping == 'parcelshopgls'){
			
?>
<script type="text/javascript">
		var lityInstance = null;
        function abrirIframeGLS() {
			if (document.getElementById('ship-to-different-address-checkbox').checked) {
				var shipping_postcode = document.getElementById("shipping_postcode").value;
				var shipping_country = document.getElementById("shipping_country").value;
			} else {
				var shipping_postcode = document.getElementById("billing_postcode").value;
				var shipping_country = document.getElementById("billing_country").value;
			}
            var s = 'https://extranet.gls-spain.es/Extranet/public/asmpshop/seleccionador.aspx?css=asm&cp=' + shipping_postcode + '&pais=' + shipping_country + '&q=i&p=-1';
			lityInstance = lity(s);
        }
        function esconderIframe() {
            /* var iframe = document.getElementById("iframe1");
            iframe.style.display = "none"; */
			lityInstance.close();
        }
        window.addEventListener("message", function(event) {
			if (event.origin == "https://extranet.gls-spain.es"){
				var nombre = '';
				var data = event.data;
				var res = data.split("|");
				var codigo = res[0];
				var nombre =res[1];
				var direccion = res[2];
				var cp = res[3];
				var localidad =res[4];
				
				jQuery.post(
					wc_checkout_params.ajax_url, 
					{
						'action': 'gls_save_parcel',
						'data': { 
								codigo: codigo, 
								nombre: nombre, 
								direccion: direccion, 
								cp: cp, 
								localidad: localidad 
								},
					}
				);
				
				
				var msg = '<div class="panel panel-info"><div class="panel-heading"><h3 class="panel-title">'+"Punto de recogida seleccionado"+'</h3></div>'
						+ '<div class="panel-body">'+nombre+'</div></div>';
				if(nombre != '')	
					document.getElementById("parcelinfo").innerHTML  = msg;
				
				esconderIframe();
			}
        });
</script>
<div id="parcelinfo-container">
    <input class="button btn btn-default" type="button" value="Elegir un punto de recogida" onclick="abrirIframeGLS()" />
    <input id="Red" type="hidden" name="Red" value="-1" />
	<br>
    <div id="parcelinfo">
<?php
	$parcel_codigo = WC()->session->get('parcel_codigo');
	if (!empty($parcel_codigo)){
	$parcel_nombre = WC()->session->get('parcel_nombre');
?>
		<div class="panel panel-info">
			<div class="panel-heading">
				<h3 class="panel-title">Punto de recogida seleccionado</h3>
			</div>
			<div class="panel-body"><?php echo $parcel_nombre ?></div>
		</div>
<?php
		}
?>
	</div>
    <iframe id="iframe1" src="" style="display: none;width:100%; min-height: 600px;"></iframe>
</div>

<?php
		}
		
		if(is_checkout() && $method->id == 'shopdelint' && $chosen_shipping == 'shopdelint'){
			
?>
<script type="text/javascript">
		var lityInstance = null;
        function abrirIframeGLS() {
			if (document.getElementById('ship-to-different-address-checkbox').checked) {
				var shipping_postcode = document.getElementById("shipping_postcode").value;
				var shipping_country = document.getElementById("shipping_country").value;
			} else {
				var shipping_postcode = document.getElementById("billing_postcode").value;
				var shipping_country = document.getElementById("billing_country").value;
			}
			if (shipping_country == 'CZ') shipping_country = 42;
            var s = 'https://extranet.gls-spain.es/Extranet/public/asmpshop/seleccionador.aspx?pais=' + shipping_country + '&cp=' + shipping_postcode + '&paisDestino=ES&p=-1';
			lityInstance = lity(s);
        }
        function esconderIframe() {
            /* var iframe = document.getElementById("iframe1");
            iframe.style.display = "none"; */
			lityInstance.close();
        }
        window.addEventListener("message", function(event) {
			if (event.origin == "https://extranet.gls-spain.es"){

				var nombre = '';
				var data = event.data;
				var res = data.split("|");
				var codigo = res[0];
				var nombre =res[1];
				var direccion = res[2];
				var cp = res[3];
				var localidad =res[4];
				
				jQuery.post(
					wc_checkout_params.ajax_url, 
					{
						'action': 'gls_save_parcel',
						'data': { 
								service: 'shopdelint', 
								codigo: codigo, 
								nombre: nombre, 
								direccion: direccion, 
								cp: cp, 
								localidad: localidad 
								},
					}
				);
				
				
				var msg = '<div class="panel panel-info"><div class="panel-heading"><h3 class="panel-title">'+"Punto de recogida seleccionado"+'</h3></div>'
						+ '<div class="panel-body">'+nombre+'</div></div>';
				if(nombre != '')	
					document.getElementById("parcelinfo").innerHTML  = msg;
				
				esconderIframe();
			}
        });
</script>
<div id="parcelinfo-container">
    <input class="button btn btn-default" type="button" value="Elegir un punto de recogida" onclick="abrirIframeGLS()" />
    <input id="Red" type="hidden" name="Red" value="-1" />
	<br>
    <div id="parcelinfo">
<?php
	$parcel_codigo = WC()->session->get('parcel_codigo');
	if (!empty($parcel_codigo)){
	$parcel_nombre = WC()->session->get('parcel_nombre');
?>
		<div class="panel panel-info">
			<div class="panel-heading">
				<h3 class="panel-title">Punto de recogida seleccionado</h3>
			</div>
			<div class="panel-body"><?php echo $parcel_nombre ?></div>
		</div>
<?php
		}
?>
	</div>
    <iframe id="iframe1" src="" style="display: none;width:100%; min-height: 600px;"></iframe>
</div>

<?php
		}
	}
} 


if (!function_exists('gls_save_parcel')) {
	function gls_save_parcel() {
		$codigo = $_REQUEST['data']['codigo'];
		$nombre = $_REQUEST['data']['nombre']; 
		$direccion = $_REQUEST['data']['direccion']; 
		$cp = $_REQUEST['data']['cp']; 
		$localidad = $_REQUEST['data']['localidad']; 
		
		WC()->session->set('gls_parcel_codigo',$codigo);
		WC()->session->set('gls_parcel_nombre',$nombre);
		WC()->session->set('gls_parcel_direccion',$direccion);
		WC()->session->set('gls_parcel_cp',$cp);
		WC()->session->set('gls_parcel_localidad',$localidad);
	}
}


if (!function_exists('gls_after_checkout_validation')) {
	function gls_after_checkout_validation($data, $errors) {

		if (!is_admin() && !empty(WC()->session)) {
			$shipping_data_method_id = $data['shipping_method'][0];
 			if ($shipping_data_method_id == 'parcelshopgls' || $shipping_data_method_id == 'shopdelint'){
				if (empty(WC()->session->get('gls_parcel_codigo'))){
					$errors->add( 'validation', 'Seleccione un punto de recogida.' );
				}
			}
		}
	}
}
			
if (!function_exists('gls_parcel_process_order')) {
	function gls_parcel_process_order($order_id) {

		if (!is_admin() && !empty(WC()->session)) {
			$shipping_data_method_id = WC()->session->get('chosen_shipping_methods')[0];
 error_log("\r\n[" . date("r") . "] " . 'shipping_data_method_id: '.$shipping_data_method_id, 3, plugin_dir_path(__FILE__) . "/log/".date('Ymd').".log");

			if ($shipping_data_method_id == 'parcelshopgls' || $shipping_data_method_id == 'shopdelint'){
				if (!empty(WC()->session->get('gls_parcel_codigo'))){
					$codigo = WC()->session->get('gls_parcel_codigo');
					$nombre = WC()->session->get('gls_parcel_nombre');
					$direccion = WC()->session->get('gls_parcel_direccion');
					$cp = WC()->session->get('gls_parcel_cp');
					$localidad = WC()->session->get('gls_parcel_localidad');
					
					add_post_meta($order_id, 'gls_parcel_codigo', $codigo);
					add_post_meta($order_id, 'gls_parcel_nombre', $nombre);
					add_post_meta($order_id, 'gls_parcel_direccion', $direccion);
					add_post_meta($order_id, 'gls_parcel_cp', $cp);
					add_post_meta($order_id, 'gls_parcel_localidad', $localidad);
					
					WC()->session->set('gls_parcel_codigo','');
					WC()->session->set('gls_parcel_nombre','');
					WC()->session->set('gls_parcel_direccion','');
					WC()->session->set('gls_parcel_cp','');
					WC()->session->set('gls_parcel_localidad','');
				} 
			} else {
				delete_post_meta($order_id,'gls_parcel_codigo');
				delete_post_meta($order_id,'gls_parcel_nombre');
				delete_post_meta($order_id,'gls_parcel_direccion');
				delete_post_meta($order_id,'gls_parcel_cp');
				delete_post_meta($order_id,'gls_parcel_localidad');
			}
		}
		return $order_id;
	}
}





function gls_get_label_tracking( $order_id ){
    $order = wc_get_order( $order_id );
	return $order->get_meta( 'codbarras' );
}


function gls_get_tracking_note( $order_id ) {
	$tracking_note = get_option(GLS_Settings::$prefix . 'gls_tracking_note_txt');
	if( empty( $tracking_note ) ) {
		$tracking_note = __( 'Seguimiento de envío: {tracking-link}', 'woocommerce-gls-envios' );
	}

	$tracking_link = gls_get_tracking_link( $order_id );

	if( empty( $tracking_link ) ) {
		return '';
	}

	$tracking_note_new = str_replace('{tracking-link}', $tracking_link, $tracking_note, $count);

	if( $count == 0 ) {
		$tracking_note_new = $tracking_note . ' ' . $tracking_link;
	}

	return $tracking_note_new;
}

function gls_get_tracking_link( $order_id ) {

	$label_tracking_info = gls_get_label_tracking( $order_id );
	if( empty( $label_tracking_info ) ) {
		return '';
	}
	//$cp_destino = get_post_meta( $order_id, '_shipping_postcode', true );
	$order = wc_get_order( $order_id );
	$cp_destino = $order->get_shipping_postcode();
	
	return sprintf( __( '<a href="https://mygls.gls-spain.es/e/%s/%s" target="_blank">%s</a>', 'woocommerce-gls-envios' ), $label_tracking_info, $cp_destino, $label_tracking_info);
}

function gls_get_tracking_note_type() {
	$gls_tracking_note = get_option(GLS_Settings::$prefix . 'gls_tracking_note');
	if( isset( $gls_tracking_note ) && ( $gls_tracking_note == 'yes' ) ) {
		return 1;
	} else {
		return 0;
	}
}

function gls_add_tracking_note_email_placeholder( $string, $email ) {

	$placeholder = '{gls_tracking_note}'; 
	$order = $email->object;
	if ( ! ( $order instanceof WC_Order ) ) {
		return $string;
	}

	$tracking_note = gls_get_tracking_note( $order->get_id() );

	return str_replace( $placeholder, $tracking_note, $string );
}

function gls_tracking_note_shortcode( $atts, $content ) {

	extract(shortcode_atts(array(
		'order_id' => ''
	), $atts));

	if( $order = wc_get_order( $order_id ) ){

		return gls_get_tracking_note( $order->get_id() );

	}

	return '';
}

function gls_tracking_link_shortcode( $atts, $content ) {

	extract(shortcode_atts(array(
		'order_id' => ''
	), $atts));

	if( $order = wc_get_order( $order_id ) ){

		return gls_get_tracking_link( $order->get_id() );

	}

	return '';
}


function gls_orders_bulk_actions( $actions ) {
	$wooMassive = get_option('gls_woomassive');
	//if ($wooMassive){
if (true){
		$actions['sendgls'] = __( 'Enviar a GLS', 'woocommerce-gls-envios' );
		//$actions['printtag'] = __( 'Etiquetas GLS', 'woocommerce-gls-envios' );
	}
    return $actions;
}

function gls_orders_handle_bulk_actions($redirect_url, $action, $post_ids) {
	//print_r($post_ids);die;
	if ($action == 'sendgls') {
		$wooGlsEnviosPrint = new WooCommerce_Gls_Envios_Print();
		foreach ($post_ids as $orderid) {
			$wooGlsEnviosPrint->generate_gls_envio('etiqueta', $orderid, 2);
		}
		return $redirect_url;
	} elseif ($action == 'printtag') {
		$wooGlsEnviosPrint = new WooCommerce_Gls_Envios_Print();
		foreach ($post_ids as $orderid) {
			$wooGlsEnviosPrint->generate_gls_envio('etiqueta', $orderid, 2);
		}
		$wooGlsEnviosPrint->multietiquetas($post_ids);
	} else {
		return $redirect_url;
	}
}

?>
