<?php
/*
Plugin Name: GLS Envíos para WooCommerce
Plugin URI: https://gls-group.eu/
Description: Permite hacer envíos mediante GLS en la plataforma WooCommerce store.
Version: 1.4.6
Author: GLS
Author URI: https://gls-group.eu/
License: Commercial License
Copyright:
Requires at least:
Tested up to:
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Base class
 */
if (!class_exists('WooCommerce_Gls_Envios')) {

    class WooCommerce_Gls_Envios
    {

        public static $plugin_prefix;
        public static $plugin_url;
        public static $plugin_path;
        public static $plugin_basefile;

        public $writepanel;
        public $settings;
        public $print;
		
		public $plugin_slug;
		public $version;
		public $cache_key;
		public $cache_allowed;

        /**
         * Constructor
         */
        public function __construct()
        {
            self::$plugin_prefix = 'wcdn_';
            self::$plugin_basefile = plugin_basename(__FILE__);
            self::$plugin_url = plugin_dir_url(self::$plugin_basefile);
            self::$plugin_path = trailingslashit(dirname(__FILE__));
			
			$this->plugin_slug = plugin_basename( __DIR__ );
			$this->version = '1.4.6';
			$this->cache_key = 'woocommerce-gls-envios';
			$this->cache_allowed = false;

			add_filter( 'plugins_api', array( $this, 'info' ), 20, 3 );
			add_filter( 'site_transient_update_plugins', array( $this, 'update' ) );
			add_action( 'upgrader_process_complete', array( $this, 'purge' ), 10, 2 );

        }

        /**
         * Load the hooks
         */
        public function load()
        {
            // load localization
            if ($this->is_woocommerce_activated()) {
                load_plugin_textdomain('woocommerce-gls-envios', false, dirname(self::$plugin_basefile) . '/../../languages/woocommerce-delivery-notes/');
                load_plugin_textdomain('woocommerce-gls-envios', false, dirname(self::$plugin_basefile) . '/languages');
            }

            // load the hooks
            add_action('init', array($this, 'load_hooks'));
						
        }

        /**
         * Load the main plugin classes and functions
         */
        public function includes()
        {
            include_once 'classes/class-gls-writepanel.php';
            include_once 'classes/class-gls-settings.php';
            include_once 'classes/class-gls-print.php';
            include_once 'classes/class-gls-table.php';
            include_once 'classes/class-gls-shipping.php';
            include_once 'classes/class-gls-wsdl.php';
            //include_once 'classes/class-gls-updatechecker.php';
        }

		public function checkDB()
        {
			global $wpdb;
			
			$table = $wpdb->prefix . 'gls_services_cost';
			$rs = $wpdb->get_results("SHOW COLUMNS FROM {$table} LIKE 'extra'");
			if (empty($rs)) {
				$sql = "ALTER TABLE `{$table}`
						ADD `extra` DECIMAL(10,2) NOT NULL AFTER `cost`;";

				$query_result = $wpdb->query( $sql );
			}
        }

		public function request(){

			$remote = get_transient( $this->cache_key );

			if( false === $remote || ! $this->cache_allowed ) {

				$remote = wp_remote_get(
					'https://resources.gls-spain.es/Woocommerce/Update/info.txt',
					//'https://glswoo.elucubracion.net/update/info.txt',
					array(
						'timeout' => 10,
						'headers' => array(
							'Accept' => 'text/plain'
						)
					)
				);

				if(
					is_wp_error( $remote )
					|| 200 !== wp_remote_retrieve_response_code( $remote )
					|| empty( wp_remote_retrieve_body( $remote ) )
				) {
					error_log("\r\n[" . date("r") . "] " . 'Error json:'.print_r($remote,1), 3, plugin_dir_path(__FILE__) . "/log/".date('Ymd').".log");
					return false;
				}

				set_transient( $this->cache_key, $remote, 60 );

			}

			$remote = json_decode( wp_remote_retrieve_body( $remote ) );

			return $remote;

		}


		function info( $res, $action, $args ) {

			if( 'plugin_information' !== $action ) {
				return $res;
			}

			if( $this->plugin_slug !== $args->slug ) {
				return $res;
			}

			$remote = $this->request();

			if( ! $remote ) {
				return $res;
			}

			$res = new stdClass();

			$res->name = $remote->name;
			$res->slug = $remote->slug;
			$res->version = $remote->version;
			$res->tested = $remote->tested;
			$res->requires = $remote->requires;
			$res->author = $remote->author;
			$res->author_profile = $remote->author_profile;
			$res->download_link = $remote->download_url;
			$res->trunk = $remote->download_url;
			$res->requires_php = $remote->requires_php;
			$res->last_updated = $remote->last_updated;

			$res->sections = array(
				'description' => $remote->sections->description,
				'installation' => $remote->sections->installation,
				'changelog' => $remote->sections->changelog
			);

			if( ! empty( $remote->banners ) ) {
				$res->banners = array(
					/* 'low' => $remote->banners->low,
					'high' => $remote->banners->high */
				);
			}

			return $res;

		}

		public function update( $transient ) {

			if ( empty($transient->checked ) ) {
				return $transient;
			}

			$remote = $this->request();

			if(
				$remote
				&& version_compare( $this->version, $remote->version, '<' )
				&& version_compare( $remote->requires, get_bloginfo( 'version' ), '<=' )
				&& version_compare( $remote->requires_php, PHP_VERSION, '<' )
			) {
				$res = new stdClass();
				$res->slug = $this->plugin_slug;
				$res->plugin = plugin_basename( __FILE__ );
				$res->new_version = $remote->version;
				$res->tested = $remote->tested;
				$res->package = $remote->download_url;

				$transient->response[ $res->plugin ] = $res;

	    }

			return $transient;

		}

		public function purge( $upgrader, $options ){

			if (
				$this->cache_allowed
				&& 'update' === $options['action']
				&& 'plugin' === $options[ 'type' ]
			) {
				delete_transient( $this->cache_key );
			}
			gls_check_options();
		}


        /**
         * Load the init hooks
         */
        public function load_hooks()
        {
            if ($this->is_woocommerce_activated()) {
                $this->includes();
                $this->checkDB();
                $this->writepanel = new WooCommerce_Gls_Envios_Writepanel();
                $this->writepanel->load();
                $this->print = new WooCommerce_Gls_Envios_Print();
                $this->print->load();                
            }            
        }

        /**
         * Add various support links to plugin page
         */
        public function add_support_links($links, $file)
        {
            if (!current_user_can('install_plugins')) {
                return $links;
            }

            if ($file == WooCommerce_Gls_Envios::$plugin_basefile) {
                $links[] = '<a href="http://wordpress.org/extend/plugins/woocommerce-gls-envios/faq/" target="_blank" title="' . __('FAQ', 'woocommerce-gls-envios') . '">' . __('FAQ', 'woocommerce-gls-envios') . '</a>';
                $links[] = '<a href="http://wordpress.org/support/plugin/woocommerce-gls-envios" target="_blank" title="' . __('Soporte', 'woocommerce-gls-envios') . '">' . __('Soporte', 'woocommerce-gls-envios') . '</a>';
            }
            return $links;
        }

        /**
         * Add settings link to plugin page
         */
        public function add_settings_link($links)
        {
            $settings = sprintf('<a href="%s" title="%s">%s</a>', admin_url('admin.php?page=woocommerce&tab=' . $this->settings->tab_name), __('Ir a la página de configuración', 'woocommerce-gls-envios'), __('Configuración', 'woocommerce-gls-envios'));
            array_unshift($links, $settings);
            return $links;
        }

        /**
         * Check if woocommerce is activated
         */
        public function is_woocommerce_activated()
        {
            if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
                return true;
            }

            if (is_multisite() && (array_key_exists('woocommerce/woocommerce.php', apply_filters('active_plugins', get_site_option('active_sitewide_plugins'))))) {
                return true;
            }

            return false;
        }
    }
}

/**
 * Instance of plugin
 */
$wcdn = new WooCommerce_Gls_Envios();
$wcdn->load();

include_once 'functions.php';

/* INSTALL AND ACTIVATION FUNCTIONS */
register_activation_hook(__FILE__, 'gls_install');
register_uninstall_hook(__FILE__, 'gls_uninstall');
register_deactivation_hook (__FILE__, 'gls_deactivate');
/* GENERAL FUNCTIONS */
add_action('admin_menu', 'register_gls_submenu_page', 99);
//add_action('woocommerce_shipping_init', 'gls_shipping_method_init');
add_filter('woocommerce_shipping_methods', 'add_gls_shipping_method');
add_filter('woocommerce_shipping_rate_method_id', 'gls_shipping_rate_method_id');
/* ORDER STATUSES */
add_action('init', 'gls_register_order_statuses');
add_filter('wc_order_statuses', 'gls_add_order_statuses');
add_action("woocommerce_order_status_changed", "gls_order_status_change");
/* PAYMENT METHOD */
//add_action('woocommerce_after_order_object_save', 'gls_update_payment_method' );
add_action('woocommerce_checkout_order_processed', 'gls_update_payment_method');
/* AJAX ACTIONS */
add_action('wp_ajax_gls_check_service', 'gls_check_service');
add_action('wp_ajax_gls_range_add', 'gls_range_add');
add_action('wp_ajax_gls_range_del', 'gls_range_del');
add_action('wp_ajax_gls_cost_update', 'gls_cost_update');
//add_action('wp_ajax_generate_gls_envio', 'generate_gls_envio_ajax');
add_action('wp_ajax_call_gls_pickut', 'call_gls_pickut');
add_action('woocommerce_after_shipping_rate', 'gls_show_parcels', 10, 2 ); 
add_action('wp_ajax_gls_save_parcel', 'gls_save_parcel' );
add_action('wp_ajax_nopriv_gls_save_parcel', 'gls_save_parcel' );
add_action('woocommerce_new_order', 'gls_parcel_process_order', 10, 1);
add_action('woocommerce_after_checkout_validation', 'gls_after_checkout_validation', 10, 2);

/* TRACKING*/
add_filter( 'woocommerce_email_format_string' , 'gls_add_tracking_note_email_placeholder', 10, 2 );
add_shortcode( 'gls_ib_tracking_note', 'gls_tracking_note_shortcode' );
add_shortcode( 'gls_ib_tracking_link', 'gls_tracking_link_shortcode' );

/* JAVASCRIPT FUNCTIONS */
add_action('wp_enqueue_scripts', 'gls_enqueue_scripts');
add_action('admin_enqueue_scripts', 'gls_admin_enqueue_scripts');
/* CRON JOB TO CHANGE ORDERS STATUS */
add_filter('cron_schedules', 'gls_init_schedule');
add_action('gls_cron_hook', 'gls_cron_job');
//$res = wp_next_scheduled('gls_cron_hook');
/* if(!wp_next_scheduled('gls_cron_job')) {
    add_action('init', 'gls_cron_job');
} */
	add_filter('bulk_actions-edit-shop_order', 'gls_orders_bulk_actions', 99, 2 );
	add_filter('handle_bulk_actions-edit-shop_order', 'gls_orders_handle_bulk_actions', 10, 3);
	add_filter('bulk_actions-woocommerce_page_wc-orders', 'gls_orders_bulk_actions', 99, 2 );
	add_filter('handle_bulk_actions-woocommerce_page_wc-orders', 'gls_orders_handle_bulk_actions', 10, 3);


add_action('admin_init', array('GLS_Settings','gls_envios_init_options'));
//add_action('admin_notices', 'gls_oldoptions_message');

add_action( 'before_woocommerce_init', function() {
    if ( !class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) )
        return;
    \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
} );

?>
